@@ -1,24 +1,36 @@
 /*  Part of SWI-Prolog
 
     Author:        Jan Wielemaker
-    E-mail:        J.Wielemak@vu.nl
+    E-mail:        J.Wielemaker@vu.nl
     WWW:           http://www.swi-prolog.org
-    Copyright (C): 1985-2012, University of Amsterdam
-			      VU University Amsterdam
+    Copyright (c)  2008-2017, University of Amsterdam
+                              VU University Amsterdam
+    All rights reserved.
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Lesser General Public
-    License as published by the Free Software Foundation; either
-    version 2.1 of the License, or (at your option) any later version.
+    Redistribution and use in source and binary forms, with or without
+    modification, are permitted provided that the following conditions
+    are met:
 
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Lesser General Public License for more details.
+    1. Redistributions of source code must retain the above copyright
+       notice, this list of conditions and the following disclaimer.
 
-    You should have received a copy of the GNU Lesser General Public
-    License along with this library; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+    2. Redistributions in binary form must reproduce the above copyright
+       notice, this list of conditions and the following disclaimer in
+       the documentation and/or other materials provided with the
+       distribution.
+
+    THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
+    "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
+    LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
+    FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
+    COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
+    INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
+    BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
+    LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
+    CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
+    LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN
+    ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
+    POSSIBILITY OF SUCH DAMAGE.
 */
 
 #ifndef _FLI_H_INCLUDED
@@ -53,10 +65,15 @@ extern "C" {
 #endif
 
 /* PLVERSION: 10000 * <Major> + 100 * <Minor> + <Patch> */
+/* PLVERSION_TAG: a string, normally "", but for example "rc1" */
 
 #ifndef PLVERSION
-#define PLVERSION 60206
+#define PLVERSION 70600
 #endif
+#ifndef PLVERSION_TAG
+#define PLVERSION_TAG ""
+#endif
+
 
 		 /*******************************
 		 *	       EXPORT		*
@@ -152,7 +169,7 @@ typedef uintptr_t	PL_atomic_t;	/* same a word */
 typedef uintptr_t	foreign_t;	/* return type of foreign functions */
 typedef wchar_t	        pl_wchar_t;	/* Prolog wide character */
 #ifdef __cplusplus
-typedef void *		pl_function_t;	/* can only pass function as void * */
+typedef void *		pl_function_t;      /* pass function as void* */
 #else
 typedef foreign_t	(*pl_function_t)(); /* foreign language functions */
 #endif
@@ -171,7 +188,7 @@ typedef union
   atom_t a;				/* PL_ATOM */
   struct				/* PL_TERM */
   { atom_t name;
-    int    arity;
+    size_t arity;
   } t;
 } term_value_t;
 
@@ -191,6 +208,10 @@ typedef union
 #define PL_STRING	 (5)		/* const char * */
 #define PL_TERM		 (6)
 
+#define PL_NIL		 (7)		/* The constant [] */
+#define PL_BLOB		 (8)		/* non-atom blob */
+#define PL_LIST_PAIR	 (9)		/* [_|_] term */
+
 					/* PL_unify_term() */
 #define PL_FUNCTOR	 (10)		/* functor_t, arg ... */
 #define PL_LIST		 (11)		/* length, arg ... */
@@ -227,12 +248,15 @@ typedef union
 #define PL_PARTIAL_LIST	 (41)		/* a partial list */
 #define PL_CYCLIC_TERM	 (42)		/* a cyclic list/term */
 #define PL_NOT_A_LIST	 (43)		/* Object is not a list */
+					/* dicts */
+#define PL_DICT		 (44)
 
 /* Or'ed flags for PL_set_prolog_flag() */
 /* MUST fit in a short int! */
 #define FF_READONLY	 0x1000		/* Read-only prolog flag */
 #define FF_KEEP		 0x2000		/* keep prolog flag if already set */
 #define FF_NOCREATE	 0x4000		/* Fail if flag is non-existent */
+#define FF_FORCE	 0x8000		/* Force setting, overwrite READONLY */
 #define FF_MASK		 0xf000
 
 
@@ -268,6 +292,7 @@ PL_EXPORT(foreign_t)	_PL_retry_address(void *);
 PL_EXPORT(int)		PL_foreign_control(control_t);
 PL_EXPORT(intptr_t)	PL_foreign_context(control_t);
 PL_EXPORT(void *)	PL_foreign_context_address(control_t);
+PL_EXPORT(predicate_t)	PL_foreign_context_predicate(control_t);
 
 
 		/********************************
@@ -305,7 +330,7 @@ PL_EXPORT(void)		PL_load_extensions(const PL_extension *e);
 		 *	      LICENSE		*
 		 *******************************/
 
-void			PL_license(const char *license, const char *module);
+PL_EXPORT(void)		PL_license(const char *license, const char *module);
 
 		/********************************
 		*            MODULES            *
@@ -314,7 +339,17 @@ void			PL_license(const char *license, const char *module);
 PL_EXPORT(module_t)	PL_context(void);
 PL_EXPORT(atom_t)	PL_module_name(module_t module);
 PL_EXPORT(module_t)	PL_new_module(atom_t name);
-PL_EXPORT(int)		PL_strip_module(term_t in, module_t *m, term_t out);
+PL_EXPORT(int)		PL_strip_module(term_t in, module_t *m, term_t out) WUNUSED;
+
+		 /*******************************
+		 *	     CONSTANTS		*
+		 *******************************/
+
+PL_EXPORT(const atom_t) *_PL_atoms(void); /* base of reserved (meta-)atoms */
+#ifndef PL_KERNEL
+#define ATOM_nil	(_PL_atoms()[0]) /* `[]` */
+#define ATOM_dot	(_PL_atoms()[1]) /* `.` */
+#endif /*PL_KERNEL*/
 
 
 		 /*******************************
@@ -322,16 +357,25 @@ PL_EXPORT(int)		PL_strip_module(term_t in, module_t *m, term_t out);
 		 *******************************/
 
 #ifdef PL_KERNEL
-#define PL_Q_DEBUG		0x01	/* = TRUE for backward compatibility */
+#define PL_Q_DEBUG		0x0001	/* = TRUE for backward compatibility */
 #endif
-#define PL_Q_NORMAL		0x02	/* normal usage */
-#define PL_Q_NODEBUG		0x04	/* use this one */
-#define PL_Q_CATCH_EXCEPTION	0x08	/* handle exceptions in C */
-#define PL_Q_PASS_EXCEPTION	0x10	/* pass to parent environment */
+#define PL_Q_NORMAL		0x0002	/* normal usage */
+#define PL_Q_NODEBUG		0x0004	/* use this one */
+#define PL_Q_CATCH_EXCEPTION	0x0008	/* handle exceptions in C */
+#define PL_Q_PASS_EXCEPTION	0x0010	/* pass to parent environment */
+#define PL_Q_ALLOW_YIELD	0x0020	/* Support I_YIELD */
+#define PL_Q_EXT_STATUS		0x0040	/* Return extended status */
 #ifdef PL_KERNEL
-#define PL_Q_DETERMINISTIC	0x20	/* call was deterministic */
+#define PL_Q_DETERMINISTIC	0x0100	/* call was deterministic */
 #endif
 
+					/* PL_Q_EXT_STATUS return codes */
+#define PL_S_EXCEPTION	       -1	/* Query raised exception */
+#define PL_S_FALSE		0	/* Query failed */
+#define PL_S_TRUE		1	/* Query succeeded with choicepoint */
+#define PL_S_LAST		2	/* Query succeeded without CP */
+
+
 			/* Foreign context frames */
 PL_EXPORT(fid_t)	PL_open_foreign_frame(void);
 PL_EXPORT(void)		PL_rewind_foreign_frame(fid_t cid);
@@ -343,7 +387,7 @@ PL_EXPORT(predicate_t)	PL_pred(functor_t f, module_t m);
 PL_EXPORT(predicate_t)	PL_predicate(const char *name, int arity,
 				     const char* module);
 PL_EXPORT(int)		PL_predicate_info(predicate_t pred,
-					  atom_t *name, int *arity,
+					  atom_t *name, size_t *arity,
 					  module_t *module);
 
 			/* Call-back */
@@ -352,6 +396,7 @@ PL_EXPORT(qid_t)	PL_open_query(module_t m, int flags,
 PL_EXPORT(int)		PL_next_solution(qid_t qid) WUNUSED;
 PL_EXPORT(void)		PL_close_query(qid_t qid);
 PL_EXPORT(void)		PL_cut_query(qid_t qid);
+PL_EXPORT(qid_t)	PL_current_query(void);
 
 			/* Simplified (but less flexible) call-back */
 PL_EXPORT(int)		PL_call(term_t t, module_t m);
@@ -362,6 +407,8 @@ PL_EXPORT(term_t)	PL_exception(qid_t qid);
 PL_EXPORT(int)		PL_raise_exception(term_t exception);
 PL_EXPORT(int)		PL_throw(term_t exception);
 PL_EXPORT(void)		PL_clear_exception(void);
+			/* Engine-based coroutining */
+PL_EXPORT(term_t)	PL_yielded(qid_t qid);
 
 
 		 /*******************************
@@ -377,17 +424,20 @@ PL_EXPORT(void)		PL_reset_term_refs(term_t r);
 			/* Constants */
 PL_EXPORT(atom_t)	PL_new_atom(const char *s);
 PL_EXPORT(atom_t)	PL_new_atom_nchars(size_t len, const char *s);
-PL_EXPORT(atom_t)	PL_new_atom_wchars(size_t len, const wchar_t *s);
+PL_EXPORT(atom_t)	PL_new_atom_wchars(size_t len, const pl_wchar_t *s);
+PL_EXPORT(atom_t)	PL_new_atom_mbchars(int rep, size_t len, const char *s);
 PL_EXPORT(const char *)	PL_atom_chars(atom_t a);
-PL_EXPORT(const char *) PL_atom_nchars(atom_t a, size_t *len);
-PL_EXPORT(const wchar_t *) PL_atom_wchars(atom_t a, size_t *len);
+PL_EXPORT(const char *)	PL_atom_nchars(atom_t a, size_t *len);
+PL_EXPORT(const wchar_t *)	PL_atom_wchars(atom_t a, size_t *len);
 #ifndef O_DEBUG_ATOMGC
 PL_EXPORT(void)		PL_register_atom(atom_t a);
 PL_EXPORT(void)		PL_unregister_atom(atom_t a);
 #endif
+PL_EXPORT(functor_t)	PL_new_functor_sz(atom_t f, size_t a);
 PL_EXPORT(functor_t)	PL_new_functor(atom_t f, int a);
 PL_EXPORT(atom_t)	PL_functor_name(functor_t f);
 PL_EXPORT(int)		PL_functor_arity(functor_t f);
+PL_EXPORT(size_t)	PL_functor_arity_sz(functor_t f);
 
 			/* Get C-values from Prolog terms */
 PL_EXPORT(int)		PL_get_atom(term_t t, atom_t *a) WUNUSED;
@@ -395,7 +445,7 @@ PL_EXPORT(int)		PL_get_bool(term_t t, int *value) WUNUSED;
 PL_EXPORT(int)		PL_get_atom_chars(term_t t, char **a) WUNUSED;
 #define PL_get_string_chars(t, s, l) PL_get_string(t,s,l)
 					/* PL_get_string() is deprecated */
-PL_EXPORT(int)		PL_get_string(term_t t, char **s, size_t *len); WUNUSED
+PL_EXPORT(int)		PL_get_string(term_t t, char **s, size_t *len) WUNUSED;
 PL_EXPORT(int)		PL_get_chars(term_t t, char **s, unsigned int flags) WUNUSED;
 PL_EXPORT(int)		PL_get_list_chars(term_t l, char **s,
 					  unsigned int flags) WUNUSED;
@@ -412,8 +462,16 @@ PL_EXPORT(int)		PL_get_intptr(term_t t, intptr_t *i) WUNUSED;
 PL_EXPORT(int)		PL_get_pointer(term_t t, void **ptr) WUNUSED;
 PL_EXPORT(int)		PL_get_float(term_t t, double *f) WUNUSED;
 PL_EXPORT(int)		PL_get_functor(term_t t, functor_t *f) WUNUSED;
-PL_EXPORT(int)		PL_get_name_arity(term_t t, atom_t *name, int *arity) WUNUSED;
+PL_EXPORT(int)		PL_get_name_arity_sz(term_t t, atom_t *name,
+					     size_t *arity) WUNUSED;
+PL_EXPORT(int)		PL_get_compound_name_arity_sz(term_t t, atom_t *name,
+						      size_t *arity) WUNUSED;
+PL_EXPORT(int)		PL_get_name_arity(term_t t, atom_t *name,
+					  int *arity) WUNUSED;
+PL_EXPORT(int)		PL_get_compound_name_arity(term_t t, atom_t *name,
+						   int *arity) WUNUSED;
 PL_EXPORT(int)		PL_get_module(term_t t, module_t *module) WUNUSED;
+PL_EXPORT(int)		PL_get_arg_sz(size_t index, term_t t, term_t a) WUNUSED;
 PL_EXPORT(int)		PL_get_arg(int index, term_t t, term_t a) WUNUSED;
 PL_EXPORT(int)		PL_get_list(term_t l, term_t h, term_t t) WUNUSED;
 PL_EXPORT(int)		PL_get_head(term_t l, term_t h) WUNUSED;
@@ -446,6 +504,8 @@ PL_EXPORT(int)		PL_put_atom(term_t t, atom_t a);
 PL_EXPORT(int)		PL_put_bool(term_t t, int val);
 PL_EXPORT(int)		PL_put_atom_chars(term_t t, const char *chars);
 PL_EXPORT(int)		PL_put_string_chars(term_t t, const char *chars) WUNUSED;
+PL_EXPORT(int)		PL_put_chars(term_t t, int flags,
+				     size_t len, const char *chars) WUNUSED;
 PL_EXPORT(int)		PL_put_list_chars(term_t t, const char *chars) WUNUSED;
 PL_EXPORT(int)		PL_put_list_codes(term_t t, const char *chars) WUNUSED;
 PL_EXPORT(int)		PL_put_atom_nchars(term_t t, size_t l, const char *chars);
@@ -457,7 +517,7 @@ PL_EXPORT(int)		PL_put_pointer(term_t t, void *ptr) WUNUSED;
 PL_EXPORT(int)		PL_put_float(term_t t, double f) WUNUSED;
 PL_EXPORT(int)		PL_put_functor(term_t t, functor_t functor) WUNUSED;
 PL_EXPORT(int)		PL_put_list(term_t l) WUNUSED;
-PL_EXPORT(void)		PL_put_nil(term_t l);
+PL_EXPORT(int)		PL_put_nil(term_t l);
 PL_EXPORT(int)		PL_put_term(term_t t1, term_t t2);
 
 			/* construct a functor or list-cell */
@@ -483,8 +543,10 @@ PL_EXPORT(int)		PL_unify_integer(term_t t, intptr_t n) WUNUSED;
 PL_EXPORT(int)		PL_unify_float(term_t t, double f) WUNUSED;
 PL_EXPORT(int)		PL_unify_pointer(term_t t, void *ptr) WUNUSED;
 PL_EXPORT(int)		PL_unify_functor(term_t t, functor_t f) WUNUSED;
+PL_EXPORT(int)		PL_unify_compound(term_t t, functor_t f) WUNUSED;
 PL_EXPORT(int)		PL_unify_list(term_t l, term_t h, term_t t) WUNUSED;
 PL_EXPORT(int)		PL_unify_nil(term_t l) WUNUSED;
+PL_EXPORT(int)		PL_unify_arg_sz(size_t index, term_t t, term_t a) WUNUSED;
 PL_EXPORT(int)		PL_unify_arg(int index, term_t t, term_t a) WUNUSED;
 PL_EXPORT(int)		PL_unify_term(term_t t, ...) WUNUSED;
 PL_EXPORT(int)		PL_unify_chars(term_t t, int flags,
@@ -518,6 +580,7 @@ PL_EXPORT(size_t)	PL_utf8_strlen(const char *s, size_t len) WUNUSED;
 
 PL_EXPORT(int)		PL_get_int64(term_t t, int64_t *i) WUNUSED;
 PL_EXPORT(int)		PL_unify_int64(term_t t, int64_t value) WUNUSED;
+PL_EXPORT(int)		PL_unify_uint64(term_t t, uint64_t value) WUNUSED;
 PL_EXPORT(int)		PL_put_int64(term_t t, int64_t i) WUNUSED;
 
 
@@ -558,7 +621,11 @@ PL_EXPORT(int)		PL_existence_error(const char *type, term_t culprit);
 PL_EXPORT(int)		PL_permission_error(const char *operation,
 					    const char *type, term_t culprit);
 PL_EXPORT(int)		PL_resource_error(const char *resource);
-
+#ifdef SIO_MAGIC
+PL_EXPORT(int)		PL_syntax_error(const char *msg, IOSTREAM *in);
+#else
+PL_EXPORT(int)		PL_syntax_error(const char *msg, void *in);
+#endif
 
 		 /*******************************
 		 *	       BLOBS		*
@@ -592,8 +659,9 @@ typedef struct PL_blob_t
   int			(*save)(atom_t a, void*);
   atom_t		(*load)(void *s);
 #endif
+  size_t		padding;	/* Required 0-padding */
 					/* private */
-  void *		reserved[10];	/* for future extension */
+  void *		reserved[9];	/* for future extension */
   int			registered;	/* Already registered? */
   int			rank;		/* Rank for ordering atoms */
   struct PL_blob_t *    next;		/* next in registered type-chain */
@@ -702,6 +770,7 @@ PL_EXPORT(void)		PL_fatal_error(const char *fmt, ...);
 PL_EXPORT(record_t)	PL_record(term_t term);
 PL_EXPORT(int)		PL_recorded(record_t record, term_t term);
 PL_EXPORT(void)		PL_erase(record_t record);
+PL_EXPORT(record_t)	PL_duplicate_record(record_t r);
 
 PL_EXPORT(char *)	PL_record_external(term_t t, size_t *size);
 PL_EXPORT(int)		PL_recorded_external(const char *rec, term_t term);
@@ -722,6 +791,7 @@ PL_EXPORT(int)		PL_set_prolog_flag(const char *name, int type, ...);
 PL_EXPORT(PL_atomic_t)	_PL_get_atomic(term_t t);
 PL_EXPORT(void)		_PL_put_atomic(term_t t, PL_atomic_t a);
 PL_EXPORT(int)		_PL_unify_atomic(term_t t, PL_atomic_t a);
+PL_EXPORT(void)		_PL_get_arg_sz(size_t index, term_t t, term_t a);
 PL_EXPORT(void)		_PL_get_arg(int index, term_t t, term_t a);
 
 
@@ -739,12 +809,14 @@ PL_EXPORT(void)		_PL_get_arg(int index, term_t t, term_t a);
 #define CVT_ATOMIC	(CVT_NUMBER|CVT_ATOM|CVT_STRING)
 #define CVT_WRITE	0x0040
 #define CVT_WRITE_CANONICAL 0x0080
+#define CVT_WRITEQ	0x00C0
 #define CVT_ALL		(CVT_ATOMIC|CVT_LIST)
 #define CVT_MASK	0x00ff
 
 #define BUF_DISCARDABLE	0x0000
 #define BUF_RING	0x0100
 #define BUF_MALLOC	0x0200
+#define BUF_ALLOW_STACK	0x0400		/* allow pointer into (global) stack */
 
 #define CVT_EXCEPTION	0x10000		/* throw exception on error */
 #define CVT_VARNOFAIL	0x20000		/* return 2 if argument is unbound */
@@ -777,7 +849,10 @@ UNICODE file functions.
 #define PL_open_stream  PL_unify_stream	/* compatibility */
 PL_EXPORT(int)		PL_unify_stream(term_t t, IOSTREAM *s);
 PL_EXPORT(int)		PL_get_stream_handle(term_t t, IOSTREAM **s);
+PL_EXPORT(int)		PL_get_stream(term_t t, IOSTREAM **s, int flags);
+PL_EXPORT(IOSTREAM*)	PL_acquire_stream(IOSTREAM *s);
 PL_EXPORT(int)		PL_release_stream(IOSTREAM *s);
+PL_EXPORT(int)		PL_release_stream_noerror(IOSTREAM *s);
 PL_EXPORT(IOSTREAM *)	PL_open_resource(module_t m,
 					 const char *name,
 					 const char *rc_class,
@@ -810,10 +885,15 @@ PL_EXPORT(IOSTREAM *)*_PL_streams(void);	/* base of streams */
 	 PL_WRT_ATTVAR_PORTRAY)
 #define PL_WRT_BLOB_PORTRAY	0x400	/* Use portray to emit non-text blobs */
 #define PL_WRT_NO_CYCLES	0x800	/* Never emit @(Template,Subst) */
-#define PL_WRT_LIST	       0x1000	/* Write [...], even with ignoreops */
 #define PL_WRT_NEWLINE	       0x2000	/* Add a newline */
+#define PL_WRT_VARNAMES	       0x4000	/* Internal: variable_names(List)  */
+#define PL_WRT_BACKQUOTE_IS_SYMBOL 0x8000 /* ` is a symbol char */
+#define PL_WRT_DOTLISTS	       0x10000	/* Write lists as .(A,B) */
+#define PL_WRT_BRACETERMS      0x20000	/* Write {A} as {}(A) */
+#define PL_WRT_NODICT	       0x40000	/* Do not write dicts in pretty syntax */
+#define PL_WRT_NODOTINATOM     0x80000	/* never write a.b unquoted */
 
-PL_EXPORT(int) PL_write_term(IOSTREAM *s,
+PL_EXPORT(int)	PL_write_term(IOSTREAM *s,
 			     term_t term,
 			     int precedence,
 			     int flags);
@@ -827,7 +907,11 @@ PL_EXPORT(int)		PL_ttymode(IOSTREAM *s);
 
 #endif /*SIO_MAGIC*/
 
-PL_EXPORT(int) PL_chars_to_term(const char *chars,
+PL_EXPORT(int)  PL_put_term_from_chars(term_t t, int flags,
+				       size_t len, const char *s);
+PL_EXPORT(int)	PL_chars_to_term(const char *chars,
+				term_t term);
+PL_EXPORT(int)	PL_wchars_to_term(const pl_wchar_t *chars,
 				 term_t term);
 
 
@@ -837,15 +921,12 @@ PL_EXPORT(int) PL_chars_to_term(const char *chars,
 
 PL_EXPORT(int)		PL_initialise(int argc, char **argv);
 PL_EXPORT(int)		PL_is_initialised(int *argc, char ***argv);
-#ifdef __CYGWIN__
-PL_EXPORT(void)		PL_install_readline(void);
-#else
-install_t		PL_install_readline(void);
-#endif
+PL_EXPORT(int)		PL_set_resource_db_mem(const unsigned char *data,
+					       size_t size);
 PL_EXPORT(int)		PL_toplevel(void);
 PL_EXPORT(int)		PL_cleanup(int status);
 PL_EXPORT(void)		PL_cleanup_fork();
-PL_EXPORT(void)		PL_halt(int status) NORETURN;
+PL_EXPORT(int)		PL_halt(int status);
 
 		 /*******************************
 		 *      INPUT/PROMPT/ETC	*
@@ -854,9 +935,8 @@ PL_EXPORT(void)		PL_halt(int status) NORETURN;
 /* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 NOTE: the functions in this section are   not  documented, as as yet not
 adviced for public usage.  They  are   intended  to  provide an abstract
-interface for the GNU readline  interface   as  defined in pl-rl.c. This
-abstract interface is necessary to make an embeddable system without the
-readline overhead.
+interface for the GNU readline  interface   as  defined  in the readline
+package.
 - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
 					/* PL_dispatch() modes */
 #define PL_DISPATCH_NOWAIT    0		/* Dispatch only once */
@@ -869,7 +949,7 @@ PL_EXPORT(char *)	PL_prompt_string(int fd);
 PL_EXPORT(void)		PL_write_prompt(int dowrite);
 PL_EXPORT(void)		PL_prompt_next(int fd);
 PL_EXPORT(char *)	PL_atom_generator(const char *prefix, int state);
-PL_EXPORT(pl_wchar_t*)  PL_atom_generator_w(const pl_wchar_t *pref,
+PL_EXPORT(pl_wchar_t*)	PL_atom_generator_w(const pl_wchar_t *pref,
 					    pl_wchar_t *buffer,
 					    size_t buflen,
 					    int state);
@@ -913,13 +993,30 @@ PL_EXPORT(PL_agc_hook_t)	PL_agc_hook(PL_agc_hook_t);
 		*            SIGNALS            *
 		*********************************/
 
+/* PL_signal() masks (deprecated) */
 #define PL_SIGSYNC	0x00010000	/* call handler synchronously */
 #define PL_SIGNOFRAME	0x00020000	/* Do not create a Prolog frame */
 
+#define PLSIG_THROW     0x0002		/* throw signal(num, name) */
+#define PLSIG_SYNC      0x0004		/* call synchronously */
+#define PLSIG_NOFRAME   0x0008		/* Do not create a Prolog frame */
+
+
+
+
+typedef struct pl_sigaction
+{ void        (*sa_cfunction)(int);	/* traditional C function */
+  predicate_t sa_predicate;		/* call a predicate */
+  int	      sa_flags;			/* additional flags */
+  void       *reserved[2];		/* future extentions */
+} pl_sigaction_t;
+
+
 PL_EXPORT(void) (*PL_signal(int sig, void (*func)(int)))(int);
-PL_EXPORT(void) PL_interrupt(int sig);
-PL_EXPORT(int)  PL_raise(int sig);
-PL_EXPORT(int)  PL_handle_signals(void);
+PL_EXPORT(int)  PL_sigaction(int sig, pl_sigaction_t *act, pl_sigaction_t *old);
+PL_EXPORT(void)	PL_interrupt(int sig);
+PL_EXPORT(int)	PL_raise(int sig);
+PL_EXPORT(int)	PL_handle_signals(void);
 PL_EXPORT(int)	PL_get_signum_ex(term_t sig, int *n);
 
 
@@ -939,13 +1036,20 @@ PL_EXPORT(int)	PL_get_signum_ex(term_t sig, int *n);
 #define PL_ACTION_GUIAPP	10	/* Win32: set when this is a gui */
 #define PL_ACTION_ATTACH_CONSOLE 11	/* MT: Attach a console */
 #define PL_GMP_SET_ALLOC_FUNCTIONS 12	/* GMP: do not change allocation functions */
+#define PL_ACTION_TRADITIONAL	13	/* Set --traditional */
 
 #define PL_BT_SAFE		0x1	/* Do not try to print goals */
 #define PL_BT_USER		0x2	/* Only show user-goals */
 
 PL_EXPORT(int)	PL_action(int, ...);	/* perform some action */
-PL_EXPORT(void) PL_on_halt(void (*)(int, void *), void *);
-PL_EXPORT(void) PL_backtrace(int depth, int flags);
+PL_EXPORT(void)	PL_on_halt(int (*)(int, void *), void *);
+PL_EXPORT(void)	PL_exit_hook(int (*)(int, void *), void *);
+PL_EXPORT(void)	PL_backtrace(int depth, int flags);
+PL_EXPORT(char *) PL_backtrace_string(int depth, int flags);
+PL_EXPORT(int)	PL_check_data(term_t data);
+PL_EXPORT(int)	PL_check_stacks(void);
+PL_EXPORT(int)	PL_current_prolog_flag(atom_t name, int type, void *ptr);
+
 
 		/********************************
 		*         QUERY PROLOG          *
@@ -973,6 +1077,9 @@ PL_EXPORT(intptr_t)	PL_query(int);	/* get information from Prolog */
 		 *	  PROLOG THREADS	*
 		 *******************************/
 
+#define PL_THREAD_NO_DEBUG	0x01	/* Start thread in nodebug mode */
+#define PL_THREAD_NOT_DETACHED	0x02	/* Allow Prolog to join */
+
 typedef struct
 { long	    local_size;			/* Stack sizes (Kbytes) */
   long	    global_size;
@@ -980,12 +1087,13 @@ typedef struct
   long	    argument_size;
   char *    alias;			/* alias name */
   int	  (*cancel)(int id);		/* cancel function */
-  void *    reserved[5];		/* reserved for extensions */
+  intptr_t  flags;			/* PL_THREAD_* flags */
+  void *    reserved[4];		/* reserved for extensions */
 } PL_thread_attr_t;
 
 
 PL_EXPORT(int)	PL_thread_self(void);	/* Prolog thread id (-1 if none) */
-PL_EXPORT(int)  PL_unify_thread_id(term_t t, int i);
+PL_EXPORT(int)	PL_unify_thread_id(term_t t, int i);
 PL_EXPORT(int)	PL_get_thread_id_ex(term_t t, int *idp);
 PL_EXPORT(int)	PL_get_thread_alias(int tid, atom_t *alias);	/* Locks alias */
 PL_EXPORT(int)	PL_thread_attach_engine(PL_thread_attr_t *attr);
@@ -995,9 +1103,9 @@ PL_EXPORT(int)	PL_thread_at_exit(void (*function)(void *),
 				  int global);
 PL_EXPORT(int)	PL_thread_raise(int tid, int sig);
 #if defined(_WINDOWS_) || defined(_WINDOWS_H)	/* <windows.h> is included */
-PL_EXPORT(int) PL_w32thread_raise(DWORD dwTid, int sig);
-PL_EXPORT(int) PL_wait_for_console_input(void *handle);
-PL_EXPORT(int) PL_w32_wrap_ansi_console(void);
+PL_EXPORT(int)	PL_w32thread_raise(DWORD dwTid, int sig);
+PL_EXPORT(int)	PL_wait_for_console_input(void *handle);
+PL_EXPORT(int)	PL_w32_wrap_ansi_console(void);
 #endif
 
 		 /*******************************
@@ -1060,10 +1168,10 @@ typedef struct
   } value;
 } xpceref_t;
 
-PL_EXPORT(int) _PL_get_xpce_reference(term_t t, xpceref_t *ref);
-PL_EXPORT(int) _PL_unify_xpce_reference(term_t t, xpceref_t *ref);
-PL_EXPORT(int) _PL_put_xpce_reference_i(term_t t, uintptr_t r);
-PL_EXPORT(int) _PL_put_xpce_reference_a(term_t t, atom_t name);
+PL_EXPORT(int)	_PL_get_xpce_reference(term_t t, xpceref_t *ref);
+PL_EXPORT(int)	_PL_unify_xpce_reference(term_t t, xpceref_t *ref);
+PL_EXPORT(int)	_PL_put_xpce_reference_i(term_t t, uintptr_t r);
+PL_EXPORT(int)	_PL_put_xpce_reference_a(term_t t, atom_t name);
 
 
 
@@ -1090,6 +1198,22 @@ PL_EXPORT(int)	PL_step_context(struct pl_context_t *c);
 PL_EXPORT(int)	PL_describe_context(struct pl_context_t *c,
 				    char *buf, size_t len);
 
+#ifdef PL_ARITY_AS_SIZE
+#define PL_new_functor(f,a) PL_new_functor_sz(f,a)
+#define PL_functor_arity(f) PL_functor_arity_sz(f)
+#define PL_get_name_arity(t,n,a) PL_get_name_arity_sz(t,n,a)
+#define PL_get_compound_name_arity(t,n,a) PL_get_compound_name_arity_sz(t,n,a)
+#define PL_get_arg(i,t,a) PL_get_arg_sz(i,t,a)
+#define PL_unify_arg(i,t,a) PL_unify_arg_sz(i,t,a)
+#ifndef _PL_INCLUDE_H
+#define _PL_get_arg(i,t,a) _PL_get_arg_sz(i,t,a)
+#endif
+#else
+//Considered too alarming
+//#warning "Term arity has changed from int to size_t."
+//#warning "Please update your code and use #define PL_ARITY_AS_SIZE 1."
+#endif
+
 #ifdef __cplusplus
 }
 #endif
