@@ -3,53 +3,12 @@
     Purpose: Provide index for autoload
 */
 
-index((r_open), 0, r_session, 'R').
-index((r_open), 1, r_session, 'R').
-index((r_start), 0, r_session, 'R').
-index((r_close), 0, r_session, 'R').
-index((r_close), 1, r_session, 'R').
-index((r_in), 1, r_session, 'R').
-index((r_in), 2, r_session, 'R').
-index((r_push), 1, r_session, 'R').
-index((r_push), 2, r_session, 'R').
-index((r_out), 2, r_session, 'R').
-index((r_out), 3, r_session, 'R').
-index((r_err), 3, r_session, 'R').
-index((r_err), 4, r_session, 'R').
-index((r_print), 1, r_session, 'R').
-index((r_print), 2, r_session, 'R').
-index((r_lines_print), 1, r_session, 'R').
-index((r_lines_print), 2, r_session, 'R').
-index((r_lines_print), 3, r_session, 'R').
-index((r_lib), 1, r_session, 'R').
-index((r_lib), 2, r_session, 'R').
-index((r_flush), 0, r_session, 'R').
-index((r_flush), 1, r_session, 'R').
-index((r_flush_onto), 2, r_session, 'R').
-index((r_flush_onto), 3, r_session, 'R').
-index((current_r_session), 1, r_session, 'R').
-index((current_r_session), 3, r_session, 'R').
-index((default_r_session), 1, r_session, 'R').
-index((r_session_data), 3, r_session, 'R').
-index((r_streams_data), 3, r_session, 'R').
-index((r_history), 0, r_session, 'R').
-index((r_history), 1, r_session, 'R').
-index((r_history), 2, r_session, 'R').
-index((r_session_version), 1, r_session, 'R').
-index((r_bin), 1, r_session, 'R').
-index((r_bin_version), 1, r_session, 'R').
-index((r_bin_version), 2, r_session, 'R').
-index((r_verbosity), 1, r_session, 'R').
-index((<-), 2, r_session, 'R').
 index((foreach), 2, aggregate, aggregate).
 index((aggregate), 3, aggregate, aggregate).
 index((aggregate), 4, aggregate, aggregate).
 index((aggregate_all), 3, aggregate, aggregate).
 index((aggregate_all), 4, aggregate, aggregate).
 index((free_variables), 4, aggregate, aggregate).
-index((am_match), 1, am_match, am_match).
-index((am_compile), 1, am_match, am_match).
-index((am_bagof), 4, am_match, am_match).
 index((ansi_format), 3, ansi_term, ansi_term).
 index((include), 3, apply, apply).
 index((exclude), 3, apply, apply).
@@ -59,6 +18,7 @@ index((maplist), 2, apply, apply).
 index((maplist), 3, apply, apply).
 index((maplist), 4, apply, apply).
 index((maplist), 5, apply, apply).
+index((convlist), 3, apply, apply).
 index((foldl), 4, apply, apply).
 index((foldl), 5, apply, apply).
 index((foldl), 6, apply, apply).
@@ -68,14 +28,19 @@ index((scanl), 5, apply, apply).
 index((scanl), 6, apply, apply).
 index((scanl), 7, apply, apply).
 index((expand_phrase), 2, apply_macros, apply_macros).
+index((expand_phrase), 4, apply_macros, apply_macros).
 index((archive_open), 3, archive, archive).
+index((archive_open), 4, archive, archive).
+index((archive_create), 3, archive, archive).
 index((archive_close), 1, archive, archive).
 index((archive_property), 2, archive, archive).
 index((archive_next_header), 2, archive, archive).
 index((archive_open_entry), 2, archive, archive).
 index((archive_header_property), 2, archive, archive).
+index((archive_set_header_property), 2, archive, archive).
 index((archive_extract), 3, archive, archive).
 index((archive_entries), 2, archive, archive).
+index((archive_data_stream), 3, archive, archive).
 index((arithmetic_function), 1, arithmetic, arithmetic).
 index((arithmetic_expression_value), 2, arithmetic, arithmetic).
 index((empty_assoc), 1, assoc, assoc).
@@ -103,6 +68,7 @@ index(('$argv'), 1, backward_compatibility, backcomp).
 index(('$set_prompt'), 1, backward_compatibility, backcomp).
 index(('$strip_module'), 3, backward_compatibility, backcomp).
 index(('$declare_module'), 3, backward_compatibility, backcomp).
+index(('$module'), 2, backward_compatibility, backcomp).
 index((at_initialization), 1, backward_compatibility, backcomp).
 index((displayq), 1, backward_compatibility, backcomp).
 index((displayq), 2, backward_compatibility, backcomp).
@@ -116,6 +82,7 @@ index((read_clause), 1, backward_compatibility, backcomp).
 index((read_clause), 2, backward_compatibility, backcomp).
 index((read_variables), 2, backward_compatibility, backcomp).
 index((read_variables), 3, backward_compatibility, backcomp).
+index((read_pending_input), 3, backward_compatibility, backcomp).
 index((feature), 2, backward_compatibility, backcomp).
 index((set_feature), 2, backward_compatibility, backcomp).
 index((substring), 4, backward_compatibility, backcomp).
@@ -148,10 +115,34 @@ index((merge_set), 3, backward_compatibility, backcomp).
 index((index), 1, backward_compatibility, backcomp).
 index((hash), 1, backward_compatibility, backcomp).
 index((set_base_module), 1, backward_compatibility, backcomp).
+index((eval_license), 0, backward_compatibility, backcomp).
+index((trie_insert_new), 3, backward_compatibility, backcomp).
 index((base32), 2, base32, base32).
 index((base32), 3, base32, base32).
+index((base64_encoded), 3, base64, base64).
+index((base64_encoded), 4, base64, base64).
 index((base64), 2, base64, base64).
 index((base64), 3, base64, base64).
+index((base64url), 2, base64, base64).
+index((base64url), 3, base64, base64).
+index((bdb_init), 1, bdb, bdb).
+index((bdb_init), 2, bdb, bdb).
+index((bdb_close_environment), 1, bdb, bdb).
+index((bdb_current_environment), 1, bdb, bdb).
+index((bdb_environment_property), 2, bdb, bdb).
+index((bdb_open), 4, bdb, bdb).
+index((bdb_close), 1, bdb, bdb).
+index((bdb_closeall), 0, bdb, bdb).
+index((bdb_current), 1, bdb, bdb).
+index((bdb_put), 3, bdb, bdb).
+index((bdb_del), 3, bdb, bdb).
+index((bdb_delall), 3, bdb, bdb).
+index((bdb_enum), 3, bdb, bdb).
+index((bdb_get), 3, bdb, bdb).
+index((bdb_getall), 3, bdb, bdb).
+index((bdb_transaction), 1, bdb, bdb).
+index((bdb_transaction), 2, bdb, bdb).
+index((bdb_version), 1, bdb, bdb).
 index((listen), 3, broadcast, broadcast).
 index((listen), 2, broadcast, broadcast).
 index((unlisten), 1, broadcast, broadcast).
@@ -160,6 +151,7 @@ index((unlisten), 3, broadcast, broadcast).
 index((listening), 3, broadcast, broadcast).
 index((broadcast), 1, broadcast, broadcast).
 index((broadcast_request), 1, broadcast, broadcast).
+index((xml_write_canonical), 3, c14n2, c14n2).
 index((cgi_get_form), 1, cgi, cgi).
 index((format_to_chars), 3, charsio, charsio).
 index((format_to_chars), 4, charsio, charsio).
@@ -180,8 +172,13 @@ index((list_undefined), 0, check, check).
 index((list_undefined), 1, check, check).
 index((list_autoload), 0, check, check).
 index((list_redefined), 0, check, check).
+index((list_void_declarations), 0, check, check).
 index((list_trivial_fails), 0, check, check).
 index((list_trivial_fails), 1, check, check).
+index((list_strings), 0, check, check).
+index((list_strings), 1, check, check).
+index((check_installation), 0, check_installation, check_installation).
+index((check_installation), 1, check_installation, check_installation).
 index((check_old_last), 0, checklast, checklast).
 index((check_old_select), 0, checkselect, checkselect).
 index((chr_show_store), 1, chr, chr).
@@ -203,11 +200,42 @@ index((with_output_to_codes), 3, codesio, codesio).
 index((with_output_to_codes), 4, codesio, codesio).
 index((coinductive), 1, coinduction, coinduction).
 index((crypt), 2, crypt, crypt).
+index((crypto_n_random_bytes), 2, crypto, crypto).
+index((crypto_data_hash), 3, crypto, crypto).
+index((crypto_file_hash), 3, crypto, crypto).
+index((crypto_context_new), 2, crypto, crypto).
+index((crypto_data_context), 3, crypto, crypto).
+index((crypto_context_hash), 2, crypto, crypto).
+index((crypto_open_hash_stream), 3, crypto, crypto).
+index((crypto_stream_hash), 2, crypto, crypto).
+index((crypto_password_hash), 2, crypto, crypto).
+index((crypto_password_hash), 3, crypto, crypto).
+index((crypto_data_hkdf), 4, crypto, crypto).
+index((ecdsa_sign), 4, crypto, crypto).
+index((ecdsa_verify), 4, crypto, crypto).
+index((crypto_data_decrypt), 6, crypto, crypto).
+index((crypto_data_encrypt), 6, crypto, crypto).
+index((hex_bytes), 2, crypto, crypto).
+index((rsa_private_decrypt), 4, crypto, crypto).
+index((rsa_private_encrypt), 4, crypto, crypto).
+index((rsa_public_decrypt), 4, crypto, crypto).
+index((rsa_public_encrypt), 4, crypto, crypto).
+index((rsa_sign), 4, crypto, crypto).
+index((rsa_verify), 4, crypto, crypto).
+index((crypto_modular_inverse), 3, crypto, crypto).
+index((crypto_generate_prime), 3, crypto, crypto).
+index((crypto_is_prime), 2, crypto, crypto).
+index((crypto_name_curve), 2, crypto, crypto).
+index((crypto_curve_order), 2, crypto, crypto).
+index((crypto_curve_generator), 2, crypto, crypto).
+index((crypto_curve_scalar_mult), 4, crypto, crypto).
 index((csv), 3, csv, csv).
 index((csv), 4, csv, csv).
 index((csv_read_file), 2, csv, csv).
 index((csv_read_file), 3, csv, csv).
 index((csv_read_file_row), 3, csv, csv).
+index((csv_read_row), 3, csv, csv).
+index((csv_options), 2, csv, csv).
 index((csv_write_file), 2, csv, csv).
 index((csv_write_file), 3, csv, csv).
 index((csv_write_stream), 3, csv, csv).
@@ -252,9 +280,20 @@ index((assertion), 1, prolog_debug, debug).
 index((expects_dialect), 1, prolog_dialect, dialect).
 index((exists_source), 1, prolog_dialect, dialect).
 index((source_exports), 2, prolog_dialect, dialect).
+index((dicts_same_tag), 2, dicts, dicts).
+index((dict_keys), 2, dicts, dicts).
+index((dicts_same_keys), 2, dicts, dicts).
+index((dicts_to_same_keys), 3, dicts, dicts).
+index((dict_fill), 4, dicts, dicts).
+index((dict_no_fill), 3, dicts, dicts).
+index((dicts_join), 3, dicts, dicts).
+index((dicts_join), 4, dicts, dicts).
+index((dicts_slice), 3, dicts, dicts).
+index((dicts_to_compounds), 4, dicts, dicts).
 index((dif), 2, dif, dif).
 index((doc_save), 2, pldoc_files, doc_files).
 index((doc_pack), 1, pldoc_files, doc_files).
+index((doc_enable), 1, pldoc_http, doc_http).
 index((doc_server), 1, pldoc_http, doc_http).
 index((doc_server), 2, pldoc_http, doc_http).
 index((doc_browser), 0, pldoc_http, doc_http).
@@ -274,15 +313,34 @@ index((nodebug), 0, edinburgh, edinburgh).
 index((fileerrors), 2, edinburgh, edinburgh).
 index((edit), 1, prolog_edit, edit).
 index((edit), 0, prolog_edit, edit).
+index((el_wrap), 0, editline, editline).
+index((el_wrap), 4, editline, editline).
+index((el_wrapped), 1, editline, editline).
+index((el_unwrap), 1, editline, editline).
+index((el_source), 2, editline, editline).
+index((el_bind), 2, editline, editline).
+index((el_addfn), 4, editline, editline).
+index((el_cursor), 2, editline, editline).
+index((el_line), 2, editline, editline).
+index((el_insertstr), 2, editline, editline).
+index((el_deletestr), 2, editline, editline).
+index((el_history), 2, editline, editline).
+index((el_history_events), 2, editline, editline).
+index((el_add_history), 2, editline, editline).
+index((el_write_history), 2, editline, editline).
+index((el_read_history), 2, editline, editline).
 index((type_error), 2, error, error).
 index((domain_error), 2, error, error).
 index((existence_error), 2, error, error).
 index((permission_error), 3, error, error).
 index((instantiation_error), 1, error, error).
+index((uninstantiation_error), 1, error, error).
 index((representation_error), 1, error, error).
 index((syntax_error), 1, error, error).
+index((resource_error), 1, error, error).
 index((must_be), 2, error, error).
 index((is_of_type), 2, error, error).
+index((current_type), 3, error, error).
 index((explain), 1, prolog_explain, explain).
 index((explain), 2, prolog_explain, explain).
 index((fast_read), 1, fastrw, fastrw).
@@ -294,6 +352,7 @@ index((can_open_file), 2, files, files).
 index((chdir), 1, files, files).
 index((set_time_file), 3, files_ex, filesex).
 index((link_file), 3, files_ex, filesex).
+index((chmod), 2, files_ex, filesex).
 index((relative_file_name), 3, files_ex, filesex).
 index((directory_file_path), 3, files_ex, filesex).
 index((copy_file), 2, files_ex, filesex).
@@ -321,6 +380,8 @@ index((git_shortlog), 3, git, git).
 index((git_log_data), 3, git, git).
 index((git_show), 4, git, git).
 index((git_commit_data), 3, git, git).
+index((open_hash_stream), 3, hash_stream, hash_stream).
+index((stream_hash), 2, hash_stream, hash_stream).
 index((add_to_heap), 4, heaps, heaps).
 index((delete_from_heap), 4, heaps, heaps).
 index((empty_heap), 1, heaps, heaps).
@@ -340,10 +401,24 @@ index((predicate), 5, help_index, helpidx).
 index((section), 4, help_index, helpidx).
 index((function), 3, help_index, helpidx).
 index((load_hotfixes), 1, prolog_hotfix, hotfix).
+index((open_any), 5, iostream, iostream).
+index((close_any), 1, iostream, iostream).
 index((iso_639_2), 2, iso_639, iso_639).
 index((iso_639_3), 2, iso_639, iso_639).
 index((iso_639), 2, iso_639, iso_639).
 index((isub), 4, isub, isub).
+index((lazy_list), 2, lazy_lists, lazy_lists).
+index((lazy_list), 3, lazy_lists, lazy_lists).
+index((lazy_list_materialize), 1, lazy_lists, lazy_lists).
+index((lazy_list_length), 2, lazy_lists, lazy_lists).
+index((lazy_findall), 3, lazy_lists, lazy_lists).
+index((lazy_findall), 4, lazy_lists, lazy_lists).
+index((lazy_get_codes), 4, lazy_lists, lazy_lists).
+index((lazy_read_terms), 4, lazy_lists, lazy_lists).
+index((lazy_read_lines), 4, lazy_lists, lazy_lists).
+index((lazy_message_queue), 4, lazy_lists, lazy_lists).
+index((lazy_engine_next), 4, lazy_lists, lazy_lists).
+index((lazy_list_iterator), 4, lazy_lists, lazy_lists).
 index((listing), 0, prolog_listing, listing).
 index((listing), 1, prolog_listing, listing).
 index((portray_clause), 1, prolog_listing, listing).
@@ -382,21 +457,28 @@ index((union), 3, lists, lists).
 index((subset), 2, lists, lists).
 index((subtract), 3, lists, lists).
 index((main), 0, prolog_main, main).
+index((argv_options), 3, prolog_main, main).
 index((make), 0, make, make).
+index((md5_hash), 3, md5, md5).
 index((new_memory_file), 1, memory_file, memfile).
 index((free_memory_file), 1, memory_file, memfile).
 index((size_memory_file), 2, memory_file, memfile).
 index((size_memory_file), 3, memory_file, memfile).
 index((open_memory_file), 3, memory_file, memfile).
 index((open_memory_file), 4, memory_file, memfile).
+index((insert_memory_file), 3, memory_file, memfile).
+index((delete_memory_file), 3, memory_file, memfile).
 index((atom_to_memory_file), 2, memory_file, memfile).
 index((memory_file_to_atom), 2, memory_file, memfile).
 index((memory_file_to_codes), 2, memory_file, memfile).
+index((memory_file_to_string), 2, memory_file, memfile).
 index((memory_file_to_atom), 3, memory_file, memfile).
 index((memory_file_to_codes), 3, memory_file, memfile).
+index((memory_file_to_string), 3, memory_file, memfile).
+index((memory_file_substring), 5, memory_file, memfile).
+index((memory_file_line_position), 4, memory_file, memfile).
 index((utf8_position_memory_file), 3, memory_file, memfile).
-index((mime_parse), 2, mime, mime).
-index((mime_default_charset), 2, mime, mime).
+index((in_temporary_module), 3, modules, modules).
 index((nb_rb_insert), 3, nb_rbtrees, nb_rbtrees).
 index((nb_rb_get_node), 3, nb_rbtrees, nb_rbtrees).
 index((nb_rb_node_value), 2, nb_rbtrees, nb_rbtrees).
@@ -433,6 +515,7 @@ index((odbc_fetch), 3, odbc, odbc).
 index((odbc_close_statement), 1, odbc, odbc).
 index((odbc_clone_statement), 2, odbc, odbc).
 index((odbc_free_statement), 1, odbc, odbc).
+index((odbc_cancel_thread), 1, odbc, odbc).
 index((odbc_current_table), 2, odbc, odbc).
 index((odbc_current_table), 3, odbc, odbc).
 index((odbc_table_column), 3, odbc, odbc).
@@ -454,6 +537,7 @@ index((select_option), 3, swi_option, option).
 index((select_option), 4, swi_option, option).
 index((merge_options), 3, swi_option, option).
 index((meta_options), 3, swi_option, option).
+index((dict_options), 2, swi_option, option).
 index((opt_parse), 5, optparse, optparse).
 index((opt_parse), 4, optparse, optparse).
 index((opt_arguments), 3, optparse, optparse).
@@ -462,6 +546,7 @@ index((is_ordset), 1, ordsets, ordsets).
 index((list_to_ord_set), 2, ordsets, ordsets).
 index((ord_add_element), 3, ordsets, ordsets).
 index((ord_del_element), 3, ordsets, ordsets).
+index((ord_selectchk), 3, ordsets, ordsets).
 index((ord_intersect), 2, ordsets, ordsets).
 index((ord_intersect), 3, ordsets, ordsets).
 index((ord_intersection), 3, ordsets, ordsets).
@@ -492,10 +577,42 @@ index((pairs_keys), 2, pairs, pairs).
 index((group_pairs_by_key), 2, pairs, pairs).
 index((transpose_pairs), 2, pairs, pairs).
 index((map_list_to_pairs), 3, pairs, pairs).
+index((re_match), 2, pcre, pcre).
+index((re_match), 3, pcre, pcre).
+index((re_matchsub), 4, pcre, pcre).
+index((re_foldl), 6, pcre, pcre).
+index((re_split), 3, pcre, pcre).
+index((re_split), 4, pcre, pcre).
+index((re_replace), 4, pcre, pcre).
+index((re_compile), 3, pcre, pcre).
+index((re_flush), 0, pcre, pcre).
+index((re_config), 1, pcre, pcre).
 index((pdt_install_console), 0, pdt_console, pdt_console).
+index((pengine_writeln), 1, pengines_io, pengines_io).
+index((pengine_nl), 0, pengines_io, pengines_io).
+index((pengine_flush_output), 0, pengines_io, pengines_io).
+index((pengine_format), 1, pengines_io, pengines_io).
+index((pengine_format), 2, pengines_io, pengines_io).
+index((pengine_write_term), 2, pengines_io, pengines_io).
+index((pengine_write), 1, pengines_io, pengines_io).
+index((pengine_writeq), 1, pengines_io, pengines_io).
+index((pengine_display), 1, pengines_io, pengines_io).
+index((pengine_print), 1, pengines_io, pengines_io).
+index((pengine_write_canonical), 1, pengines_io, pengines_io).
+index((pengine_listing), 0, pengines_io, pengines_io).
+index((pengine_listing), 1, pengines_io, pengines_io).
+index((pengine_portray_clause), 1, pengines_io, pengines_io).
+index((pengine_read), 1, pengines_io, pengines_io).
+index((pengine_read_line_to_string), 2, pengines_io, pengines_io).
+index((pengine_read_line_to_codes), 2, pengines_io, pengines_io).
+index((pengine_io_predicate), 1, pengines_io, pengines_io).
+index((pengine_bind_io_to_html), 1, pengines_io, pengines_io).
+index((pengine_io_goal_expansion), 2, pengines_io, pengines_io).
 index((persistent), 1, persistency, persistency).
 index((current_persistent_predicate), 1, persistency, persistency).
 index((db_attach), 2, persistency, persistency).
+index((db_detach), 0, persistency, persistency).
+index((db_attached), 1, persistency, persistency).
 index((db_sync), 1, persistency, persistency).
 index((db_sync_all), 1, persistency, persistency).
 index((doc_collect), 1, pldoc, pldoc).
@@ -515,6 +632,7 @@ index((tokenize_atom), 2, porter_stem, porter_stem).
 index((atom_to_stem_list), 2, porter_stem, porter_stem).
 index((portray_text), 1, portray_text, portray_text).
 index((set_portray_text), 2, portray_text, portray_text).
+index((print_term), 2, prolog_pretty_print, pprint).
 index((predicate_options), 3, predicate_options, predicate_options).
 index((assert_predicate_options), 4, predicate_options, predicate_options).
 index((current_option_arg), 2, predicate_options, predicate_options).
@@ -535,10 +653,13 @@ index((process_id), 2, process, process).
 index((is_process), 1, process, process).
 index((process_release), 1, process, process).
 index((process_kill), 1, process, process).
+index((process_group_kill), 1, process, process).
+index((process_group_kill), 2, process, process).
 index((process_kill), 2, process, process).
 index((autoload), 0, prolog_autoload, prolog_autoload).
 index((autoload), 1, prolog_autoload, prolog_autoload).
 index((set_breakpoint), 4, prolog_breakpoints, prolog_breakpoints).
+index((set_breakpoint), 5, prolog_breakpoints, prolog_breakpoints).
 index((delete_breakpoint), 1, prolog_breakpoints, prolog_breakpoints).
 index((breakpoint_property), 2, prolog_breakpoints, prolog_breakpoints).
 index((clause_info), 4, prolog_clause, prolog_clause).
@@ -549,9 +670,16 @@ index((prolog_walk_code), 1, prolog_codewalk, prolog_codewalk).
 index((prolog_program_clause), 2, prolog_codewalk, prolog_codewalk).
 index((prolog_colourise_stream), 3, prolog_colour, prolog_colour).
 index((prolog_colourise_term), 4, prolog_colour, prolog_colour).
+index((prolog_colourise_query), 3, prolog_colour, prolog_colour).
 index((syntax_colour), 2, prolog_colour, prolog_colour).
 index((syntax_message), 3, prolog_colour, prolog_colour).
+index((format_spec), 2, prolog_format, prolog_format).
+index((format_spec), 3, prolog_format, prolog_format).
+index((format_types), 2, prolog_format, prolog_format).
 index((prolog_history), 1, prolog_history, prolog_history).
+index((qcompile_libraries), 0, prolog_install, prolog_install).
+index((jiti_list), 0, prolog_jiti, prolog_jiti).
+index((jiti_list), 1, prolog_jiti, prolog_jiti).
 index((infer_meta_predicate), 2, prolog_metainference, prolog_metainference).
 index((inferred_meta_predicate), 2, prolog_metainference, prolog_metainference).
 index((pack_list_installed), 0, prolog_pack, prolog_pack).
@@ -565,6 +693,7 @@ index((pack_rebuild), 1, prolog_pack, prolog_pack).
 index((pack_rebuild), 0, prolog_pack, prolog_pack).
 index((pack_remove), 1, prolog_pack, prolog_pack).
 index((pack_property), 2, prolog_pack, prolog_pack).
+index((pack_url_file), 2, prolog_pack, prolog_pack).
 index((prolog_server), 2, prolog_server, prolog_server).
 index((prolog_read_source_term), 4, prolog_source, prolog_source).
 index((read_source_term_at_location), 3, prolog_source, prolog_source).
@@ -582,6 +711,7 @@ index((prolog_stack_frame_property), 2, prolog_stack, prolog_stack).
 index((print_prolog_backtrace), 2, prolog_stack, prolog_stack).
 index((print_prolog_backtrace), 3, prolog_stack, prolog_stack).
 index((backtrace), 1, prolog_stack, prolog_stack).
+index((open_prolog_stream), 4, prolog_stream, prolog_stream).
 index((xref_source), 1, prolog_xref, prolog_xref).
 index((xref_source), 2, prolog_xref, prolog_xref).
 index((xref_called), 3, prolog_xref, prolog_xref).
@@ -592,6 +722,7 @@ index((xref_exported), 2, prolog_xref, prolog_xref).
 index((xref_module), 2, prolog_xref, prolog_xref).
 index((xref_uses_file), 3, prolog_xref, prolog_xref).
 index((xref_op), 2, prolog_xref, prolog_xref).
+index((xref_prolog_flag), 4, prolog_xref, prolog_xref).
 index((xref_comment), 3, prolog_xref, prolog_xref).
 index((xref_comment), 4, prolog_xref, prolog_xref).
 index((xref_mode), 3, prolog_xref, prolog_xref).
@@ -615,11 +746,11 @@ index((protobuf_message), 2, protobufs, protobufs).
 index((protobuf_message), 3, protobufs, protobufs).
 index((phrase_from_file), 2, pure_input, pure_input).
 index((phrase_from_file), 3, pure_input, pure_input).
+index((phrase_from_stream), 2, pure_input, pure_input).
+index((stream_to_lazy_list), 2, pure_input, pure_input).
 index((syntax_error), 3, pure_input, pure_input).
 index((lazy_list_location), 3, pure_input, pure_input).
 index((lazy_list_character_count), 3, pure_input, pure_input).
-index((phrase_from_stream), 2, pure_input, pure_input).
-index((stream_to_lazy_list), 2, pure_input, pure_input).
 index((pwp_files), 2, pwp, pwp).
 index((pwp_stream), 3, pwp, pwp).
 index((pwp_xml), 3, pwp, pwp).
@@ -693,20 +824,17 @@ index((rb_lookup), 3, rbtrees, rbtrees).
 index((rb_update), 4, rbtrees, rbtrees).
 index((rb_update), 5, rbtrees, rbtrees).
 index((rb_apply), 4, rbtrees, rbtrees).
-index((rb_lookupall), 3, rbtrees, rbtrees).
 index((rb_insert), 4, rbtrees, rbtrees).
 index((rb_insert_new), 4, rbtrees, rbtrees).
 index((rb_delete), 3, rbtrees, rbtrees).
 index((rb_delete), 4, rbtrees, rbtrees).
 index((rb_visit), 2, rbtrees, rbtrees).
-index((rb_visit), 3, rbtrees, rbtrees).
 index((rb_keys), 2, rbtrees, rbtrees).
-index((rb_keys), 3, rbtrees, rbtrees).
 index((rb_map), 2, rbtrees, rbtrees).
 index((rb_map), 3, rbtrees, rbtrees).
 index((rb_partial_map), 4, rbtrees, rbtrees).
+index((rb_fold), 4, rbtrees, rbtrees).
 index((rb_clone), 3, rbtrees, rbtrees).
-index((rb_clone), 4, rbtrees, rbtrees).
 index((rb_min), 3, rbtrees, rbtrees).
 index((rb_max), 3, rbtrees, rbtrees).
 index((rb_del_min), 4, rbtrees, rbtrees).
@@ -736,6 +864,10 @@ index((rdf_start_file), 2, rdf_triple, rdf_triple).
 index((rdf_end_file), 1, rdf_triple, rdf_triple).
 index((anon_prefix), 1, rdf_triple, rdf_triple).
 index((rdf_write_xml), 2, rdf_write, rdf_write).
+index((rl_read_init_file), 1, readline, readline).
+index((rl_add_history), 1, readline, readline).
+index((rl_write_history), 1, readline, readline).
+index((rl_read_history), 1, readline, readline).
 index((readln), 1, readln, readln).
 index((readln), 2, readln, readln).
 index((readln), 5, readln, readln).
@@ -744,6 +876,8 @@ index((read_line_to_codes), 3, read_util, readutil).
 index((read_stream_to_codes), 2, read_util, readutil).
 index((read_stream_to_codes), 3, read_util, readutil).
 index((read_file_to_codes), 3, read_util, readutil).
+index((read_line_to_string), 2, read_util, readutil).
+index((read_file_to_string), 3, read_util, readutil).
 index((read_file_to_terms), 3, read_util, readutil).
 index((record), 1, record, record).
 index((current_record), 2, record, record).
@@ -752,7 +886,9 @@ index((rewrite), 2, rewrite, rewrite).
 index((rew_term_expansion), 2, rewrite, rewrite).
 index((rew_goal_expansion), 2, rewrite, rewrite).
 index((rlimit), 3, clib_rlimit, rlimit).
+index((saml_authenticate), 4, saml, saml).
 index((safe_goal), 1, sandbox, sandbox).
+index((safe_call), 1, sandbox, sandbox).
 index((setting), 4, settings, settings).
 index((setting), 2, settings, settings).
 index((set_setting), 2, settings, settings).
@@ -793,6 +929,8 @@ index((xml_quote_attribute), 2, sgml, sgml).
 index((xml_quote_cdata), 2, sgml, sgml).
 index((xml_name), 1, sgml, sgml).
 index((xml_name), 2, sgml, sgml).
+index((xsd_number_string), 2, sgml, sgml).
+index((xsd_time_string), 3, sgml, sgml).
 index((xml_basechar), 1, sgml, sgml).
 index((xml_ideographic), 1, sgml, sgml).
 index((xml_combining_char), 1, sgml, sgml).
@@ -813,6 +951,7 @@ index((sha_hash_ctx), 4, crypto_hash, sha).
 index((hmac_sha), 4, crypto_hash, sha).
 index((file_sha1), 2, crypto_hash, sha).
 index((hash_atom), 2, crypto_hash, sha).
+index((shell), 0, shell, shell).
 index((ls), 0, shell, shell).
 index((ls), 1, shell, shell).
 index((cd), 0, shell, shell).
@@ -852,25 +991,34 @@ index((tcp_open_socket), 2, socket, socket).
 index((udp_socket), 1, socket, socket).
 index((udp_receive), 4, socket, socket).
 index((udp_send), 4, socket, socket).
+index((negotiate_socks_connection), 2, socket, socket).
+index((distinct), 1, solution_sequences, solution_sequences).
+index((distinct), 2, solution_sequences, solution_sequences).
+index((reduced), 1, solution_sequences, solution_sequences).
+index((reduced), 3, solution_sequences, solution_sequences).
+index((limit), 2, solution_sequences, solution_sequences).
+index((offset), 2, solution_sequences, solution_sequences).
+index((order_by), 2, solution_sequences, solution_sequences).
+index((group_by), 4, solution_sequences, solution_sequences).
 index((predsort), 3, sort, sort).
 index((locale_sort), 2, sort, sort).
 index((load_certificate), 2, ssl, ssl).
 index((load_private_key), 3, ssl, ssl).
 index((load_public_key), 2, ssl, ssl).
 index((load_crl), 2, ssl, ssl).
-index((rsa_private_decrypt), 3, ssl, ssl).
-index((rsa_private_encrypt), 3, ssl, ssl).
-index((rsa_public_decrypt), 3, ssl, ssl).
-index((rsa_public_encrypt), 3, ssl, ssl).
+index((system_root_certificates), 1, ssl, ssl).
+index((cert_accept_any), 5, ssl, ssl).
 index((ssl_context), 3, ssl, ssl).
-index((ssl_init), 3, ssl, ssl).
-index((ssl_accept), 3, ssl, ssl).
-index((ssl_open), 3, ssl, ssl).
-index((ssl_open), 4, ssl, ssl).
+index((ssl_add_certificate_key), 4, ssl, ssl).
+index((ssl_set_options), 3, ssl, ssl).
 index((ssl_negotiate), 5, ssl, ssl).
-index((ssl_exit), 1, ssl, ssl).
+index((ssl_peer_certificate), 2, ssl, ssl).
+index((ssl_peer_certificate_chain), 2, ssl, ssl).
 index((ssl_session), 2, ssl, ssl).
+index((ssl_secure_ciphers), 1, ssl, ssl).
 index((statistics), 0, prolog_statistics, statistics).
+index((statistics), 1, prolog_statistics, statistics).
+index((thread_statistics), 2, prolog_statistics, statistics).
 index((time), 1, prolog_statistics, statistics).
 index((profile), 1, prolog_statistics, statistics).
 index((profile), 2, prolog_statistics, statistics).
@@ -910,8 +1058,14 @@ index((sub_string), 3, table, table).
 index((table_version), 2, table, table).
 index((sort_table), 2, table_util, table_util).
 index((verify_table_order), 1, table_util, table_util).
+index((table), 1, tabling, tabling).
+index((current_table), 2, tabling, tabling).
+index((abolish_all_tables), 0, tabling, tabling).
+index((abolish_table_subgoals), 1, tabling, tabling).
+index((start_tabling), 2, tabling, tabling).
 index((term_hash), 2, terms, terms).
 index((term_hash), 4, terms, terms).
+index((term_size), 2, terms, terms).
 index((term_variables), 2, terms, terms).
 index((term_variables), 3, terms, terms).
 index((variant), 2, terms, terms).
@@ -938,8 +1092,10 @@ index((thread_run_interactor), 0, thread_util, threadutil).
 index((threads), 0, thread_util, threadutil).
 index((join_threads), 0, thread_util, threadutil).
 index((interactor), 0, thread_util, threadutil).
+index((interactor), 1, thread_util, threadutil).
 index((thread_has_console), 0, thread_util, threadutil).
 index((attach_console), 0, thread_util, threadutil).
+index((attach_console), 1, thread_util, threadutil).
 index((tspy), 1, thread_util, threadutil).
 index((tspy), 2, thread_util, threadutil).
 index((tdebug), 0, thread_util, threadutil).
@@ -976,7 +1132,7 @@ index((reachable), 3, ugraphs, ugraphs).
 index((top_sort), 2, ugraphs, ugraphs).
 index((top_sort), 3, ugraphs, ugraphs).
 index((transitive_closure), 2, ugraphs, ugraphs).
-index((transpose), 2, ugraphs, ugraphs).
+index((transpose_ugraph), 2, ugraphs, ugraphs).
 index((vertices), 2, ugraphs, ugraphs).
 index((vertices_edges_to_ugraph), 3, ugraphs, ugraphs).
 index((ugraph_union), 3, ugraphs, ugraphs).
@@ -984,6 +1140,7 @@ index((getuid), 1, uid, uid).
 index((getgid), 1, uid, uid).
 index((geteuid), 1, uid, uid).
 index((getegid), 1, uid, uid).
+index((getgroups), 1, uid, uid).
 index((user_info), 2, uid, uid).
 index((group_info), 2, uid, uid).
 index((user_data), 3, uid, uid).
@@ -1038,10 +1195,13 @@ index((url_iri), 2, url, url).
 index((file_name_to_url), 2, url, url).
 index((set_url_encoding), 2, url, url).
 index((utf8_codes), 3, utf8, utf8).
+index((uuid), 1, uuid, uuid).
+index((uuid), 2, uuid, uuid).
 index((numbervars), 1, varnumbers, varnumbers).
 index((varnumbers), 2, varnumbers, varnumbers).
 index((max_var_number), 3, varnumbers, varnumbers).
 index((varnumbers), 3, varnumbers, varnumbers).
+index((varnumbers_names), 3, varnumbers, varnumbers).
 index((vm_list), 1, prolog_vm, vm).
 index((when), 2, when, when).
 index((init_win_menus), 0, win_menu, win_menu).
@@ -1051,6 +1211,10 @@ index((swritef), 2, writef, writef).
 index((swritef), 3, writef, writef).
 index((www_open_url), 1, www_browser, www_browser).
 index((expand_url_path), 2, www_browser, www_browser).
+index((xmld_signed_DOM), 3, xmldsig, xmldsig).
+index((xmld_verify_signature), 4, xmldsig, xmldsig).
+index((decrypt_xml), 4, xmlenc, xmlenc).
+index((load_certificate_from_base64_string), 2, xmlenc, xmlenc).
 index((xpath), 3, xpath, xpath).
 index((xpath_chk), 3, xpath, xpath).
 index((xsdp_type), 1, xsdp_type, xsdp_types).
@@ -1058,6 +1222,25 @@ index((xsdp_uri_type), 2, xsdp_type, xsdp_types).
 index((xsdp_numeric_uri), 2, xsdp_type, xsdp_types).
 index((xsdp_subtype_of), 2, xsdp_type, xsdp_types).
 index((xsdp_convert), 3, xsdp_type, xsdp_types).
+index((>>), 2, yall, yall).
+index((>>), 3, yall, yall).
+index((>>), 4, yall, yall).
+index((>>), 5, yall, yall).
+index((>>), 6, yall, yall).
+index((>>), 7, yall, yall).
+index((>>), 8, yall, yall).
+index((>>), 9, yall, yall).
+index((/), 2, yall, yall).
+index((/), 3, yall, yall).
+index((/), 4, yall, yall).
+index((/), 5, yall, yall).
+index((/), 6, yall, yall).
+index((/), 7, yall, yall).
+index((/), 8, yall, yall).
+index((/), 9, yall, yall).
+index((lambda_calls), 2, yall, yall).
+index((lambda_calls), 3, yall, yall).
+index((is_lambda), 1, yall, yall).
 index((zopen), 3, zlib, zlib).
 index((gzopen), 3, zlib, zlib).
 index((gzopen), 4, zlib, zlib).
