@@ -1,8 +1,37 @@
-%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
-% Author:	Tom Schrijvers
-% Email:	Tom.Schrijvers@cs.kuleuven.be
-% Copyright:	K.U.Leuven 2004
-%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+/*  Part of CHR (Constraint Handling Rules)
+
+    Author:        Tom Schrijvers
+    E-mail:        Tom.Schrijvers@cs.kuleuven.be
+    WWW:           http://www.swi-prolog.org
+    Copyright (c)  2004-2016, K.U. Leuven
+    All rights reserved.
+
+    Redistribution and use in source and binary forms, with or without
+    modification, are permitted provided that the following conditions
+    are met:
+
+    1. Redistributions of source code must retain the above copyright
+       notice, this list of conditions and the following disclaimer.
+
+    2. Redistributions in binary form must reproduce the above copyright
+       notice, this list of conditions and the following disclaimer in
+       the documentation and/or other materials provided with the
+       distribution.
+
+    THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
+    "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
+    LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
+    FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
+    COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
+    INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
+    BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
+    LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
+    CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
+    LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN
+    ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
+    POSSIBILITY OF SUCH DAMAGE.
+*/
+
 :- module(builtins,
 	[
 		negate_b/2,
@@ -11,7 +40,7 @@
 		builtin_binds_b/2
 	]).
 
-:- use_module(hprolog).
+:- use_module(library(dialect/hprolog)).
 
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 negate_b(A,B) :- once(negate(A,B)).
@@ -52,8 +81,8 @@ entails_b(A,B) :-
 entails(A,A,_).
 entails(A,C,History) :-
 	entails_(A,B),
-	\+ hprolog:memberchk_eq(B,History),
-	entails(B,C,[B|History]).		
+	\+ memberchk_eq(B,History),
+	entails(B,C,[B|History]).
 
 entails_(X > Y, X >= Y).
 entails_(X > Y, Y < X).
@@ -127,7 +156,7 @@ builtin_binds_(true,L,L).
 % builtin_binds_(writeln(_),L,L).
 % builtin_binds_(writeq(_), L, L).
 % builtin_binds_(writeq(_, _), L, L).
-% 
+%
 % builtin_binds_(!(_), L, L).
 % builtin_binds_(!, L, L).
 % builtin_binds_((_'|'_), L, L).
@@ -426,7 +455,8 @@ builtin_binds_(true,L,L).
 % builtin_binds_(read_clause(_, _), L, L).
 % builtin_binds_(read_history(_, _, _, _, _, _), L, L).
 % builtin_binds_(read_link(_, _, _), L, L).
-% builtin_binds_(read_pending_input(_, _, _), L, L).
+% builtin_binds_(read_pending_codes(_, _, _), L, L).
+% builtin_binds_(read_pending_chars(_, _, _), L, L).
 % builtin_binds_(read_term(_, _), L, L).
 % builtin_binds_(read_term(_, _, _), L, L).
 % builtin_binds_(recorda(_, _), L, L).
@@ -481,8 +511,8 @@ builtin_binds_(true,L,L).
 % builtin_binds_(string(_), L, L).
 % builtin_binds_(string_concat(_, _, _), L, L).
 % builtin_binds_(string_length(_, _), L, L).
-% builtin_binds_(string_to_atom(_, _), L, L).
-% builtin_binds_(string_to_list(_, _), L, L).
+% builtin_binds_(atom_string(_, _), L, L).
+% builtin_binds_(string_codes(_, _), L, L).
 % builtin_binds_(strip_module(_, _, _), L, L).
 % builtin_binds_(style_check(_), L, L).
 % builtin_binds_(sub_atom(_, _, _, _, _), L, L).
