@@ -1,39 +1,38 @@
-/*  $Id$
-
-    Part of CHR (Constraint Handling Rules)
+/*  Part of CHR (Constraint Handling Rules)
 
     Author:        Christian Holzbaur and Tom Schrijvers
     E-mail:        christian@ai.univie.ac.at
-		   Tom.Schrijvers@cs.kuleuven.be
+                   Tom.Schrijvers@cs.kuleuven.be
     WWW:           http://www.swi-prolog.org
-    Copyright (C): 2003-2004, K.U. Leuven
+    Copyright (c)  2004-2015, K.U. Leuven
+    All rights reserved.
 
-    This program is free software; you can redistribute it and/or
-    modify it under the terms of the GNU General Public License
-    as published by the Free Software Foundation; either version 2
-    of the License, or (at your option) any later version.
+    Redistribution and use in source and binary forms, with or without
+    modification, are permitted provided that the following conditions
+    are met:
 
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
+    1. Redistributions of source code must retain the above copyright
+       notice, this list of conditions and the following disclaimer.
 
-    You should have received a copy of the GNU Lesser General Public
-    License along with this library; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+    2. Redistributions in binary form must reproduce the above copyright
+       notice, this list of conditions and the following disclaimer in
+       the documentation and/or other materials provided with the
+       distribution.
 
-    As a special exception, if you link this library with other files,
-    compiled with a Free Software compiler, to produce an executable, this
-    library does not by itself cause the resulting executable to be covered
-    by the GNU General Public License. This exception does not however
-    invalidate any other reasons why the executable file might be covered by
-    the GNU General Public License.
-
-    Distributed with SWI-Prolog under the above conditions with
-    permission from the authors.
+    THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
+    "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
+    LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
+    FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
+    COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
+    INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
+    BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
+    LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
+    CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
+    LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN
+    ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
+    POSSIBILITY OF SUCH DAMAGE.
 */
 
-
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %%       _                             _   _
 %%   ___| |__  _ __   _ __ _   _ _ __ | |_(_)_ __ ___   ___
@@ -70,7 +69,6 @@
 
 :- module(chr_runtime,
 	  [ 'chr sbag_del_element'/3,
-	    'chr sbag_member'/2,
 	    'chr merge_attributes'/3,
 
 	    'chr run_suspensions'/1,
@@ -113,6 +111,7 @@
 
 	    'chr gen_id'/1,
 
+	    'chr debugging'/0,
 	    'chr debug_event'/1,
 	    'chr debug command'/2,	% Char, Command
 
@@ -124,8 +123,11 @@
 
 	    'chr select'/3,
 
-	    chr_show_store/1,	% +Module
-	    find_chr_constraint/1,
+	    'chr module'/1,		% ?Module
+
+	    chr_show_store/1,		% +Module
+	    find_chr_constraint/1,	% -Constraint
+	    current_chr_constraint/1,	% :Constraint
 
 	    chr_trace/0,
 	    chr_notrace/0,
@@ -136,6 +138,9 @@
 :- set_prolog_flag(generate_debug_info, false).
 %% SWI end
 
+:- meta_predicate
+	current_chr_constraint(:).
+
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 
 :- use_module(library(dialect/hprolog)).
@@ -196,10 +201,41 @@ chr_show_store(Mod) :-
 		true
 	).
 
+%%	find_chr_constraint(-Constraint) is nondet.
+%
+%	True when Constraint is a  currently   known  constraint  in any
+%	known CHR module.
+%
+%	@deprecated	current_chr_constraint/1 handles modules.
+
 find_chr_constraint(Constraint) :-
-	chr:'$chr_module'(Mod),
+	'chr module'(Mod),
 	Mod:'$enumerate_constraints'(Constraint).
 
+%%	current_chr_constraint(:Constraint) is nondet.
+%
+%	True if Constraint is a constraint associated with the qualified
+%	module.
+
+current_chr_constraint(Mod:Constraint) :-
+	'chr module'(Mod),
+	Mod:'$enumerate_constraints'(Constraint).
+
+%%	'chr module'(?Module)
+%
+%	True when Module is a CHR module.   The  first clause deals with
+%	normal modules. The second with temporary modules, which are not
+%	allowed to generate clauses for chr:'$chr_module'/1.
+
+'chr module'(Module) :-
+	chr:'$chr_module'(Module).
+:- if(current_prolog_flag(dialect, swi)).
+'chr module'(Module) :-
+	module_property(Module, class(temporary)),
+	current_predicate(Module:'$chr_initialization'/0),
+	\+ predicate_property(Module:'$chr_initialization', imported_from(_)).
+:- endif.
+
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 % Inlining of some goals is good for performance
 % That's the reason for the next section
@@ -325,6 +361,7 @@ run_suspensions_d([S|Next] ) :-
 %- attribute handler -----------------------------------------------------------
 %	intercepts unification of locked variable unification
 
+:- public locked:attr_unify_hook/2.
 locked:attr_unify_hook(_,_) :- fail.
 
 %- locking & unlocking ---------------------------------------------------------
@@ -508,9 +545,11 @@ unerror_lockv([T|R]) :- del_attr( T, error_locked), unerror_lockv(R).
 		'chr default_store'(V)
 	).
 
+:- if(\+current_predicate(nonground/2)).
 nonground( Term, V) :-
 	term_variables( Term, Vs),
 	Vs = [V|_].
+:- endif.
 
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 'chr novel_production'( Self, Tuple) :-
@@ -629,15 +668,6 @@ insert_constraint_internal([Global|Vars], Self, Term, Closure, F, Args) :-
 
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 
-'chr sbag_member'( Element, [Head|Tail]) :-
-      sbag_member( Element, Tail, Head).
-
-% auxiliary to avoid choicepoint for last element
-        % does it really avoid the choicepoint? -jon
- sbag_member( E, _,	     E).
- sbag_member( E, [Head|Tail], _) :-
-	sbag_member( E, Tail, Head).
-
 'chr sbag_del_element'( [],	  _,	[]).
 'chr sbag_del_element'( [X|Xs], Elem, Set2) :-
 	( X==Elem ->
@@ -724,13 +754,17 @@ all_suspensions([APos-ASusps|RAttr],Susps,SuspsList,Pos) :-
 	chr:debug_event/2,		% +State, +Event
 	chr:debug_interact/3.		% +Event, +Depth, -Command
 
+'chr debugging' :-
+	nb_getval(chr_debug,mutable(trace)).
+
 'chr debug_event'(Event) :-
-	nb_getval(chr_debug,mutable(State)),  % XXX
-	( State == off ->
-		true
-	; chr:debug_event(State, Event) ->
-		true
-	;	debug_event(State,Event)
+	(   nb_getval(chr_debug,mutable(State)),
+	    State \== off
+	->  (   chr:debug_event(State, Event)
+	    ->  true
+	    ;	debug_event(State,Event)
+	    )
+	;   true
 	).
 
 chr_trace :-
@@ -874,15 +908,20 @@ leashed(Event) :-
 	nb_getval(chr_leash, mutable(Ports)),
 	memberchk(Port, Ports).
 
+:- multifile
+	chr:debug_ask_continue/1.
+
 ask_continue(Command) :-
-	print_message(debug, chr(prompt)),
+	chr:debug_ask_continue(Command), !.
+ask_continue(Command) :-
+	print_message(trace, chr(prompt)),
 	get_single_char(CharCode),
 	(   CharCode == -1
 	->  Char = end_of_file
 	;   char_code(Char, CharCode)
 	),
 	(   debug_command(Char, Command)
-	->  print_message(debug, chr(command(Command)))
+	->  print_message(trace, chr(command(Command)))
 	;   print_message(help, chr(invalid_command)),
 	    ask_continue(Command)
 	).
@@ -910,12 +949,11 @@ handle_debug_command(skip, Event, Depth) :- !,
 	Event =.. [Type|Rest],
 	( Type \== call,
 	  Type \== wake ->
-		handle_debug_command('c',Event,Depth)
+		handle_debug_command(creep,Event,Depth)
 	;
 		Rest = [Susp],
 		set_chr_debug(skip(Susp,Depth))
 	).
-
 handle_debug_command(ancestors,Event,Depth) :- !,
 	print_chr_debug_history,
 	chr_debug_interact(Event,Depth).
@@ -924,7 +962,10 @@ handle_debug_command(nodebug,_,_) :- !,
 handle_debug_command(abort,_,_) :- !,
 	abort.
 handle_debug_command(exit,_,_) :- !,
-	halt.
+	(   thread_self(main)		% Only allow terminating from the
+	->  halt			% main thread
+	;   permission_error(access, chr_debug, halt)
+	).
 handle_debug_command(fail,_,_) :- !,
 	fail.
 handle_debug_command(break,Event,Depth) :- !,
@@ -938,10 +979,10 @@ handle_debug_command(Cmd, _, _) :-
 
 print_chr_debug_history :-
 	get_debug_history(History,Depth),
-	print_message(debug, chr(ancestors(History, Depth))).
+	print_message(trace, chr(ancestors(History, Depth))).
 
 print_event(Event, Depth) :-
-	print_message(debug, chr(event(Event, Depth))).
+	print_message(trace, chr(event(Event, Depth))).
 
 %	{set,get}_debug_history(Ancestors, Depth)
 %
@@ -962,3 +1003,13 @@ set_chr_debug(State) :-
 'chr chr_indexed_variables'(Susp,Vars) :-
         Susp =.. [_,_,_,_,_,_,_|Args],
 	term_variables(Args,Vars).
+
+
+		 /*******************************
+		 *	      SANDBOX		*
+		 *******************************/
+:- multifile
+	sandbox:safe_primitive/1.
+
+sandbox:safe_primitive(chr_runtime:handle_debug_command(_,_,_)).
+sandbox:safe_primitive(chr_runtime:ask_continue(_)).
