@@ -1,4 +1,4 @@
-/*  
+/*
 
     Part of CLP(Q) (Constraint Logic Programming over Rationals)
 
@@ -14,7 +14,7 @@
     This software is based on CLP(Q,R) by Christian Holzbaur for SICStus
     Prolog and distributed under the license details below with permission from
     all mentioned authors.
-    
+
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
     as published by the Free Software Foundation; either version 2
@@ -433,7 +433,7 @@ iterate_dec(OptVar,Opt) :-
 	->  iterate_dec(OptVar,Opt)
 	;   Status = optimum,
 	    Opt is R + I
- 	).
+	).
 
 % iterate_inc(OptVar,Opt)
 %
@@ -567,7 +567,7 @@ dec_step([l(V*K,OrdV)|Vs],Status) :-
 	(   dec_step_2(W,l(V*K,OrdV),Class,Status)
 	->  true
 	;   dec_step(Vs,Status)
-	).   
+	).
 
 dec_step_2(t_U(U),l(V*K,OrdV),Class,Status) :-
 	K > 0,
@@ -596,7 +596,7 @@ dec_step_2(t_Lu(L,U),l(V*K,OrdV),Class,applied) :-
 	class_basis(Class,Deps),
 	ub(Deps,OrdV,V-t_lU(L,U)-Init,Vub-Vb-_),
 	pivot_b(Vub,V,Vb,t_lu(L,U)).
-dec_step_2(t_none,l(V*_,_),_,unlimited(V,t_none)).	
+dec_step_2(t_none,l(V*_,_),_,unlimited(V,t_none)).
 
 inc_step([],optimum).	% if status has not been set yet: no changes
 inc_step([l(V*K,OrdV)|Vs],Status) :-
@@ -696,12 +696,12 @@ ub([Dep|Deps],OrdX,T0,T1) :-
 % See lb_inner/5: this is similar
 
 ub_inner(t_l(L),OrdX,Lin,t_L(L),Ub) :-
-	nf_rhs_x(Lin,OrdX,Rhs,K), 
+	nf_rhs_x(Lin,OrdX,Rhs,K),
 	K < 0,
 	Ub is (L - Rhs) rdiv K.
 ub_inner(t_u(U),OrdX,Lin,t_U(U),Ub) :-
 	nf_rhs_x(Lin,OrdX,Rhs,K),
- 	K > 0,
+	K > 0,
 	Ub is (U - Rhs) rdiv K.
 ub_inner(t_lu(L,U),OrdX,Lin,W,Ub) :-
 	nf_rhs_x(Lin,OrdX,Rhs,K),
@@ -830,10 +830,10 @@ solve(H,Lin,_,Bind0,BindT) :-
 	;   Category = 2 % class variable, no bounds
 	->  arg(6,Att,class(NewC)),
 	    class_allvars(NewC,Deps),
- 	    (   ClassesUniq = [_] % rank increasing
+	    (   ClassesUniq = [_] % rank increasing
 	    ->	bs_collect_bindings(Deps,Ord,Lin1,Bind0,BindT)
 	    ;   Bind0 = BindT,
-	    	bs(Deps,Ord,Lin1)
+		bs(Deps,Ord,Lin1)
 	    ),
 	    eq_classes(NV,NVT,ClassesUniq)
 	;   Category = 3 % classless variable, all variables in Lin and
@@ -892,7 +892,7 @@ solve_x(H,Lin,_,X,Bind0,BindT) :-
 	(   arg(6,Att,class(NewC))
 	->  class_allvars(NewC,Deps),
 	    (   ClassesUniq = [_] % rank increasing
-	    -> 	bs_collect_bindings(Deps,OrdX,Lin1,Bind0,BindT)
+	    ->	bs_collect_bindings(Deps,OrdX,Lin1,Bind0,BindT)
 	    ;   Bind0 = BindT,
 		bs(Deps,OrdX,Lin1)
 	    ),
@@ -949,7 +949,7 @@ sd([l(X*K,_)|Xs],Class0,ClassN,Preference0,PreferenceN,NV0,NVt) :-
 	    ;   preference(Preference0,4-X-K,Preference1)
 		    % has class, is bounded => category 4
 	    )
-  	;   % new: has no class
+	;   % new: has no class
 	    Class1 = Class0,
 	    NV0 = [X|NV1], % X has no class yet, add to list of new variables
 	    (   arg(2,Att,type(t_none))
@@ -958,7 +958,7 @@ sd([l(X*K,_)|Xs],Class0,ClassN,Preference0,PreferenceN,NV0,NVt) :-
 	    ;   preference(Preference0,3-X-K,Preference1)
 		    % no class, is bounded => category 3
 	    )
-  	),
+	),
 	sd(Xs,Class1,ClassN,Preference1,PreferenceN,NV1,NVt).
 
 %
@@ -969,7 +969,7 @@ preference(A,B,Pref) :-
 	B = Py-_-_,
 	(   Px < Py
 	->  Pref = A
-  	;   Pref = B
+	;   Pref = B
 	).
 
 % eq_classes(NV,NVTail,Cs)
@@ -1150,7 +1150,7 @@ determine_active_inc([_,_|H]) :-
 determine_active([],_).
 determine_active([l(X*K,_)|Xs],S) :-
 	get_attr(X,itf,Att),
-	arg(2,Att,type(Type)),	
+	arg(2,Att,type(Type)),
 	determine_active(Type,X,K,S),
 	determine_active(Xs,S).
 
@@ -1163,7 +1163,7 @@ determine_active(t_u(U),X,_,_) :- intro_at(X,U,t_U(U)).
 determine_active(t_lu(L,U),X,K,S) :-
 	KS is K*S,
 	(   KS < 0
-	->  intro_at(X,L,t_Lu(L,U))	
+	->  intro_at(X,L,t_Lu(L,U))
 	;   KS > 0
 	->  intro_at(X,U,t_lU(L,U))
 	).
@@ -1222,7 +1222,7 @@ basis_drop(X) :-
 	class_basis_drop(Cv,X).
 
 % basis(X,Basis)
-% 
+%
 % Basis is the basis of the class to which X belongs.
 
 basis(X,Basis) :-
@@ -1254,7 +1254,7 @@ basis_pivot(Leave,Enter) :-
 
 % pivot(Dep,Indep)
 %
-% The linear equation of variable Dep, is transformed into one of variable 
+% The linear equation of variable Dep, is transformed into one of variable
 % Indep, containing Dep. Then, all occurrences of Indep in linear equations are
 % substituted by this new definition
 
@@ -1351,7 +1351,7 @@ pivot(Dep,Class,IndepOrd,DepAct,IndAct) :-
 
 % Rewrite Dep = ... + Coeff*Indep + ...
 % into Indep = ... + -1/Coeff*Dep + ...
-% 
+%
 % For backsubstitution, old current value of Indep must be removed from RHS
 % New current value of Dep must be added to RHS
 % For solving: old current value of Indep should be out of RHS
@@ -1361,7 +1361,7 @@ pivot_vlv(Dep,Class,IndepOrd,DepAct,AbvI,Lin) :-
 	arg(4,Att,lin(H)),
 	arg(5,Att,order(DepOrd)),
 	setarg(2,Att,type(DepAct)),
-	select_active_bound(DepAct,AbvD), % New current value for Dep 
+	select_active_bound(DepAct,AbvD), % New current value for Dep
 	delete_factor(IndepOrd,H,H0,Coeff), % Dep = ... + Coeff*Indep + ...
 	AbvDm is -AbvD,
 	AbvIm is -AbvI,
@@ -1422,7 +1422,7 @@ bs([X|Xs],OrdV,Lin) :-
 %
 % E.g. when V = 2X + 3Y + 4, X = 3V + 2Z and Y = 4X + 3
 % we can substitute V in the linear equation of X: X = 6X + 9Y + 2Z + 12
-% we can't substitute V in the linear equation of Y of course. 
+% we can't substitute V in the linear equation of Y of course.
 
 bs_collect_bindings(Xs,_,_,Bind0,BindT) :-
 	var(Xs),
@@ -1461,7 +1461,7 @@ rcbl([X|Continuation],Bind0,BindT) :-
 	->  rcbl_status(Status,X,NewContinuation,Bind0,BindT,Violated)
 	;   rcbl(Continuation,Bind0,BindT)
 	).
-	
+
 rcb_cont(X,Status,Violated,ContIn,ContOut) :-
 	get_attr(X,itf,Att),
 	arg(2,Att,type(Type)),
@@ -1661,7 +1661,7 @@ narrow_l( t_lu(_,U), X, L) :-
 % Returns in Dump a representation of the linear constraint on variable
 % Var which has linear equation H + I and has type Type.
 
-dump_var(t_none,V,I,H) --> 
+dump_var(t_none,V,I,H) -->
 	!,
 	(   {
 		H = [l(W*K,_)],
@@ -1758,3 +1758,16 @@ dump_nz(_,H,I) -->
 	    nf2sum(H1,0,Sum)
 	},
 	[Sum =\= I1].
+
+		 /*******************************
+		 *	       SANDBOX		*
+		 *******************************/
+:- multifile
+	sandbox:safe_primitive/1.
+
+sandbox:safe_primitive(bv_q:inf(_,_)).
+sandbox:safe_primitive(bv_q:inf(_,_,_,_)).
+sandbox:safe_primitive(bv_q:sup(_,_)).
+sandbox:safe_primitive(bv_q:sup(_,_,_,_)).
+sandbox:safe_primitive(bv_q:maximize(_)).
+sandbox:safe_primitive(bv_q:minimize(_)).
