@@ -3,31 +3,35 @@
     Author:        Tom Schrijvers, Bart Demoen, Jan Wielemaker
     E-mail:        Tom.Schrijvers@cs.kuleuven.be
     WWW:           http://www.swi-prolog.org
-    Copyright (C): 2004-2008, K.U. Leuven
+    Copyright (c)  2008-2015, K.U. Leuven
+    All rights reserved.
 
-    This program is free software; you can redistribute it and/or
-    modify it under the terms of the GNU General Public License
-    as published by the Free Software Foundation; either version 2
-    of the License, or (at your option) any later version.
+    Redistribution and use in source and binary forms, with or without
+    modification, are permitted provided that the following conditions
+    are met:
 
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
+    1. Redistributions of source code must retain the above copyright
+       notice, this list of conditions and the following disclaimer.
 
-    You should have received a copy of the GNU General Public
-    License along with this library; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+    2. Redistributions in binary form must reproduce the above copyright
+       notice, this list of conditions and the following disclaimer in
+       the documentation and/or other materials provided with the
+       distribution.
 
-    As a special exception, if you link this library with other files,
-    compiled with a Free Software compiler, to produce an executable, this
-    library does not by itself cause the resulting executable to be covered
-    by the GNU General Public License. This exception does not however
-    invalidate any other reasons why the executable file might be covered by
-    the GNU General Public License.
+    THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
+    "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
+    LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
+    FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
+    COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
+    INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
+    BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
+    LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
+    CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
+    LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN
+    ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
+    POSSIBILITY OF SUCH DAMAGE.
 */
 
-
 :- module(hprolog,
 	  [ substitute_eq/4,		% +OldVal, +OldList, +NewVal, -NewList
 	    memberchk_eq/2,		% +Val, +List
@@ -45,18 +49,23 @@
 	    get_store/2,
 	    update_store/2,
 	    make_get_store_goal/3,
+	    make_get_store_goal_no_error/3,
 	    make_update_store_goal/3,
 	    make_init_store_goal/3,
 
 	    empty_ds/1,
 	    ds_to_list/2,
 	    get_ds/3,
-	    put_ds/4
+	    put_ds/4,
+
+	    time/3
 %	    lookup_ht1/4
 	  ]).
-:- use_module(library(lists)).
 :- use_module(library(assoc)).
 
+:- meta_predicate
+	time(0, -, -).
+
 /** <module> hProlog compatibility library
 
 This library has been developed mainly for porting the CHR package.
@@ -69,6 +78,32 @@ This library has been developed mainly for porting the CHR package.
 	into the CHR utilities.
 */
 
+                 /*******************************
+                 *          LIBRARY SETUP       *
+                 *******************************/
+
+%%      push_hprolog_library
+%
+%	Pushes searching for dialect/hprolog in front of every
+%	library directory that contains such as sub-directory.
+
+push_hprolog_library :-
+        (   absolute_file_name(library(dialect/hprolog), Dir,
+                               [ file_type(directory),
+                                 access(read),
+                                 solutions(all),
+                                 file_errors(fail)
+                               ]),
+            asserta((user:file_search_path(library, Dir) :-
+                    prolog_load_context(dialect, hprolog))),
+            fail
+        ;   true
+        ).
+
+
+:- push_hprolog_library.
+
+
 empty_ds(DS) :- empty_assoc(DS).
 ds_to_list(DS,LIST) :- assoc_to_list(DS,LIST).
 get_ds(A,B,C) :- get_assoc(A,B,C).
@@ -85,6 +120,8 @@ make_init_store_goal(Name,Value,Goal) :- Goal = nb_setval(Name,Value).
 
 make_get_store_goal(Name,Value,Goal) :- Goal = nb_getval(Name,Value).
 
+make_get_store_goal_no_error(Name,Value,Goal) :- Goal = nb_current(Name,Value).
+
 make_update_store_goal(Name,Value,Goal) :- Goal = b_setval(Name,Value).
 
 
@@ -263,3 +300,15 @@ chr_delete([H|T], X, L) :-
             chr_delete(T, X, RT)
         ).
 
+%%	time(:Goal, -CPU, -Wall)
+%
+%	hProlog compatible predicate to for statistical purposes
+
+time(Goal, CPU, Wall) :-
+	get_time(T0),
+	statistics(cputime, CPU0),
+	call(Goal),
+	statistics(cputime, CPU1),
+	get_time(T1),
+	Wall is T1-T0,
+	CPU is CPU1-CPU0.
