@@ -21,6 +21,7 @@ index((html_post), 4, html_write, html_write).
 index((html_receive), 3, html_write, html_write).
 index((html_receive), 4, html_write, html_write).
 index((xhtml_ns), 4, html_write, html_write).
+index((html_root_attribute), 4, html_write, html_write).
 index((html), 4, html_write, html_write).
 index((html_begin), 3, html_write, html_write).
 index((html_end), 3, html_write, html_write).
@@ -33,16 +34,24 @@ index((html_meta), 1, html_write, html_write).
 index((http_authenticate), 3, authenticate, http_authenticate).
 index((http_authorization_data), 2, authenticate, http_authenticate).
 index((http_current_user), 3, authenticate, http_authenticate).
+index((http_read_passwd_file), 2, authenticate, http_authenticate).
+index((http_write_passwd_file), 2, authenticate, http_authenticate).
 index((http_get), 3, http_client, http_client).
 index((http_delete), 3, http_client, http_client).
 index((http_post), 4, http_client, http_client).
 index((http_put), 4, http_client, http_client).
+index((http_patch), 4, http_client, http_client).
 index((http_read_data), 3, http_client, http_client).
 index((http_disconnect), 1, http_client, http_client).
 index((cookie_remove_client), 1, http_cookie, http_cookie).
 index((cookie_remove_all_clients), 0, http_cookie, http_cookie).
 index((cookie_current_cookie), 4, http_cookie, http_cookie).
 index((cors_enable), 0, http_cors, http_cors).
+index((cors_enable), 2, http_cors, http_cors).
+index((http_digest_challenge), 4, http_digest, http_digest).
+index((http_digest_password_hash), 4, http_digest, http_digest).
+index((http_parse_digest_challenge), 2, http_digest, http_digest).
+index((http_digest_response), 5, http_digest, http_digest).
 index((http_reply_dirindex), 3, http_dirindex, http_dirindex).
 index((directory_index), 4, http_dirindex, http_dirindex).
 index((http_dispatch), 1, http_dispatch, http_dispatch).
@@ -59,6 +68,7 @@ index((http_link_to_id), 3, http_dispatch, http_dispatch).
 index((http_reload_with_parameters), 3, http_dispatch, http_dispatch).
 index((http_safe_file), 2, http_dispatch, http_dispatch).
 index((map_exception_to_http_status), 4, http_exception, http_exception).
+index((in_or_exclude_backtrace), 2, http_exception, http_exception).
 index((http_reply_from_files), 3, http_files, http_files).
 index((http_read_request), 2, http_header, http_header).
 index((http_read_reply_header), 2, http_header, http_header).
@@ -66,6 +76,7 @@ index((http_reply), 2, http_header, http_header).
 index((http_reply), 3, http_header, http_header).
 index((http_reply), 4, http_header, http_header).
 index((http_reply), 5, http_header, http_header).
+index((http_reply), 6, http_header, http_header).
 index((http_reply_header), 3, http_header, http_header).
 index((http_status_reply), 4, http_header, http_header).
 index((http_status_reply), 5, http_header, http_header).
@@ -85,8 +96,12 @@ index((http_current_host), 4, http_host, http_host).
 index((http_log_stream), 1, http_log, http_log).
 index((http_log), 2, http_log, http_log).
 index((http_log_close), 1, http_log, http_log).
+index((post_data_encoded), 2, http_log, http_log).
+index((http_logrotate), 1, http_log, http_log).
+index((http_schedule_logrotate), 2, http_log, http_log).
 index((http_open), 3, http_open, http_open).
 index((http_set_authorization), 2, http_open, http_open).
+index((http_close_keep_alive), 1, http_open, http_open).
 index((openid_login), 1, http_openid, http_openid).
 index((openid_logout), 1, http_openid, http_openid).
 index((openid_logged_in), 1, http_openid, http_openid).
@@ -104,6 +119,8 @@ index((openid_current_host), 3, http_openid, http_openid).
 index((http_parameters), 2, http_parameters, http_parameters).
 index((http_parameters), 3, http_parameters, http_parameters).
 index((http_convert_parameter), 4, http_parameters, http_parameters).
+index((http_convert_parameters), 2, http_parameters, http_parameters).
+index((http_convert_parameters), 3, http_parameters, http_parameters).
 index((http_absolute_uri), 2, http_path, http_path).
 index((http_absolute_location), 3, http_path, http_path).
 index((http_clean_location_cache), 0, http_path, http_path).
@@ -112,6 +129,7 @@ index((pwp_handler), 2, http_pwp, http_pwp).
 index((serve_files_in_directory), 2, http_server_files, http_server_files).
 index((http_set_session_options), 1, http_session, http_session).
 index((http_set_session), 1, http_session, http_session).
+index((http_set_session), 2, http_session, http_session).
 index((http_session_option), 1, http_session, http_session).
 index((http_session_id), 1, http_session, http_session).
 index((http_in_session), 1, http_session, http_session).
@@ -126,6 +144,8 @@ index((http_session_retractall), 1, http_session, http_session).
 index((http_session_data), 1, http_session, http_session).
 index((http_chunked_open), 3, http_stream, http_stream).
 index((stream_range_open), 3, http_stream, http_stream).
+index((multipart_open), 3, http_stream, http_stream).
+index((multipart_open_next), 1, http_stream, http_stream).
 index((cgi_open), 4, http_stream, http_stream).
 index((cgi_property), 2, http_stream, http_stream).
 index((cgi_set), 2, http_stream, http_stream).
@@ -141,9 +161,14 @@ index((http_send_header), 1, httpd_wrapper, http_wrapper).
 index((http_relative_path), 2, httpd_wrapper, http_wrapper).
 index((http_wrap_spawned), 3, httpd_wrapper, http_wrapper).
 index((http_spawned), 1, httpd_wrapper, http_wrapper).
+index((hub_create), 3, hub, hub).
+index((hub_add), 3, hub, hub).
+index((hub_send), 2, hub, hub).
+index((hub_broadcast), 2, hub, hub).
+index((hub_broadcast), 3, hub, hub).
+index((current_hub), 2, hub, hub).
 index((http_server), 2, http_inetd, inetd_httpd).
 index((js_token), 3, javascript_grammar, js_grammar).
-index((js_program), 3, javascript_grammar, js_grammar).
 index((js_script), 3, javascript, js_write).
 index((js_call), 3, javascript, js_write).
 index((js_new), 4, javascript, js_write).
@@ -161,11 +186,21 @@ index((http_current_server), 2, thread_httpd, thread_httpd).
 index((http_server_property), 2, thread_httpd, thread_httpd).
 index((http_server), 2, thread_httpd, thread_httpd).
 index((http_workers), 2, thread_httpd, thread_httpd).
+index((http_add_worker), 2, thread_httpd, thread_httpd).
 index((http_current_worker), 2, thread_httpd, thread_httpd).
 index((http_stop_server), 2, thread_httpd, thread_httpd).
 index((http_spawn), 2, thread_httpd, thread_httpd).
 index((http_requeue), 1, thread_httpd, thread_httpd).
 index((http_close_connection), 1, thread_httpd, thread_httpd).
+index((http_enough_workers), 3, thread_httpd, thread_httpd).
+index((http_open_websocket), 3, websocket, websocket).
+index((http_upgrade_to_websocket), 3, websocket, websocket).
+index((ws_send), 2, websocket, websocket).
+index((ws_receive), 2, websocket, websocket).
+index((ws_receive), 3, websocket, websocket).
+index((ws_close), 3, websocket, websocket).
+index((ws_open), 3, websocket, websocket).
+index((ws_property), 2, websocket, websocket).
 index((http_current_server), 2, xpce_httpd, xpce_httpd).
 index((http_server), 2, xpce_httpd, xpce_httpd).
 index((xrds_dom), 2, yadis, yadis).
