@@ -3,6 +3,70 @@
     Purpose: Provide index for autoload
 */
 
+index((rdf), 3, rdf11, rdf11).
+index((rdf), 4, rdf11, rdf11).
+index((rdf_has), 3, rdf11, rdf11).
+index((rdf_has), 4, rdf11, rdf11).
+index((rdf_update), 4, rdf11, rdf11).
+index((rdf_update), 5, rdf11, rdf11).
+index((rdf_reachable), 3, rdf11, rdf11).
+index((rdf_reachable), 5, rdf11, rdf11).
+index((rdf_assert), 3, rdf11, rdf11).
+index((rdf_assert), 4, rdf11, rdf11).
+index((rdf_retractall), 3, rdf11, rdf11).
+index((rdf_retractall), 4, rdf11, rdf11).
+index(({}), 1, rdf11, rdf11).
+index((rdf_where), 1, rdf11, rdf11).
+index((rdf_compare), 3, rdf11, rdf11).
+index((rdf_term), 1, rdf11, rdf11).
+index((rdf_literal), 1, rdf11, rdf11).
+index((rdf_bnode), 1, rdf11, rdf11).
+index((rdf_iri), 1, rdf11, rdf11).
+index((rdf_name), 1, rdf11, rdf11).
+index((rdf_is_iri), 1, rdf11, rdf11).
+index((rdf_is_bnode), 1, rdf11, rdf11).
+index((rdf_is_literal), 1, rdf11, rdf11).
+index((rdf_is_name), 1, rdf11, rdf11).
+index((rdf_is_object), 1, rdf11, rdf11).
+index((rdf_is_predicate), 1, rdf11, rdf11).
+index((rdf_is_subject), 1, rdf11, rdf11).
+index((rdf_is_term), 1, rdf11, rdf11).
+index((rdf_subject), 1, rdf11, rdf11).
+index((rdf_predicate), 1, rdf11, rdf11).
+index((rdf_object), 1, rdf11, rdf11).
+index((rdf_node), 1, rdf11, rdf11).
+index((rdf_create_bnode), 1, rdf11, rdf11).
+index((rdf_canonical_literal), 2, rdf11, rdf11).
+index((rdf_lexical_form), 2, rdf11, rdf11).
+index((rdf_default_graph), 1, rdf11, rdf11).
+index((rdf_default_graph), 2, rdf11, rdf11).
+index((rdf_estimate_complexity), 4, rdf11, rdf11).
+index((rdf_assert_list), 2, rdf11, rdf11).
+index((rdf_assert_list), 3, rdf11, rdf11).
+index((rdf_last), 2, rdf11, rdf11).
+index((rdf_list), 1, rdf11, rdf11).
+index((rdf_list), 2, rdf11, rdf11).
+index((rdf_length), 2, rdf11, rdf11).
+index((rdf_member), 2, rdf11, rdf11).
+index((rdf_nextto), 2, rdf11, rdf11).
+index((rdf_nextto), 3, rdf11, rdf11).
+index((rdf_nth0), 3, rdf11, rdf11).
+index((rdf_nth1), 3, rdf11, rdf11).
+index((rdf_retract_list), 1, rdf11, rdf11).
+index((rdf_alt), 3, rdf11_containers, rdf11_containers).
+index((rdf_assert_alt), 3, rdf11_containers, rdf11_containers).
+index((rdf_assert_alt), 4, rdf11_containers, rdf11_containers).
+index((rdf_assert_bag), 2, rdf11_containers, rdf11_containers).
+index((rdf_assert_bag), 3, rdf11_containers, rdf11_containers).
+index((rdf_assert_seq), 2, rdf11_containers, rdf11_containers).
+index((rdf_assert_seq), 3, rdf11_containers, rdf11_containers).
+index((rdf_bag), 2, rdf11_containers, rdf11_containers).
+index((rdf_seq), 2, rdf11_containers, rdf11_containers).
+index((rdfs_container), 2, rdf11_containers, rdf11_containers).
+index((rdfs_container_membership_property), 1, rdf11_containers, rdf11_containers).
+index((rdfs_container_membership_property), 2, rdf11_containers, rdf11_containers).
+index((rdfs_member), 2, rdf11_containers, rdf11_containers).
+index((rdfs_nth0), 3, rdf11_containers, rdf11_containers).
 index((rdf_set_cache_options), 1, rdf_cache, rdf_cache).
 index((rdf_cache_file), 3, rdf_cache, rdf_cache).
 index((rdf_equal_graphs), 3, rdf_compare, rdf_compare).
@@ -71,6 +135,7 @@ index((rdf_save_footer), 1, rdf_db, rdf_db).
 index((rdf_equal), 2, rdf_db, rdf_db).
 index((lang_equal), 2, rdf_db, rdf_db).
 index((lang_matches), 2, rdf_db, rdf_db).
+index((rdf_prefix), 2, rdf_db, rdf_db).
 index((rdf_current_prefix), 2, rdf_db, rdf_db).
 index((rdf_register_prefix), 2, rdf_db, rdf_db).
 index((rdf_register_prefix), 3, rdf_db, rdf_db).
@@ -80,6 +145,7 @@ index((rdf_register_ns), 3, rdf_db, rdf_db).
 index((rdf_global_id), 2, rdf_db, rdf_db).
 index((rdf_global_object), 2, rdf_db, rdf_db).
 index((rdf_global_term), 2, rdf_db, rdf_db).
+index((rdf_compare), 3, rdf_db, rdf_db).
 index((rdf_match_label), 3, rdf_db, rdf_db).
 index((rdf_split_url), 3, rdf_db, rdf_db).
 index((rdf_url_namespace), 2, rdf_db, rdf_db).
@@ -142,8 +208,12 @@ index((rdf_library_index), 2, rdf_library, rdf_library).
 index((rdf_current_manifest), 1, rdf_library, rdf_library).
 index((rdf_set_literal_index_option), 1, rdf_litindex, rdf_litindex).
 index((rdf_tokenize_literal), 2, rdf_litindex, rdf_litindex).
+index((rdf_find_literal), 2, rdf_litindex, rdf_litindex).
 index((rdf_find_literals), 2, rdf_litindex, rdf_litindex).
 index((rdf_token_expansions), 2, rdf_litindex, rdf_litindex).
+index((rdf_stopgap_token), 1, rdf_litindex, rdf_litindex).
+index((rdf_literal_index), 2, rdf_litindex, rdf_litindex).
+index((rdf_delete_literal_index), 1, rdf_litindex, rdf_litindex).
 index((rdf_read_ntriples), 3, rdf_ntriples, rdf_ntriples).
 index((rdf_read_nquads), 3, rdf_ntriples, rdf_ntriples).
 index((rdf_process_ntriples), 3, rdf_ntriples, rdf_ntriples).
@@ -155,6 +225,7 @@ index((rdf_detach_db), 0, rdf_persistency, rdf_persistency).
 index((rdf_current_db), 1, rdf_persistency, rdf_persistency).
 index((rdf_persistency), 2, rdf_persistency, rdf_persistency).
 index((rdf_flush_journals), 1, rdf_persistency, rdf_persistency).
+index((rdf_persistency_property), 1, rdf_persistency, rdf_persistency).
 index((rdf_journal_file), 2, rdf_persistency, rdf_persistency).
 index((rdf_snapshot_file), 2, rdf_persistency, rdf_persistency).
 index((rdf_db_to_file), 2, rdf_persistency, rdf_persistency).
@@ -167,6 +238,9 @@ index((rdf_save_turtle), 2, rdf_turtle_write, rdf_turtle_write).
 index((rdf_save_canonical_turtle), 2, rdf_turtle_write, rdf_turtle_write).
 index((rdf_save_trig), 2, rdf_turtle_write, rdf_turtle_write).
 index((rdf_save_canonical_trig), 2, rdf_turtle_write, rdf_turtle_write).
+index((rdf_save_ntriples), 2, rdf_turtle_write, rdf_turtle_write).
+index((read_rdfa), 3, rdfa, rdfa).
+index((xml_rdfa), 3, rdfa, rdfa).
 index((rdfs_subproperty_of), 2, rdfs, rdfs).
 index((rdfs_subclass_of), 2, rdfs, rdfs).
 index((rdfs_class_property), 2, rdfs, rdfs).
@@ -189,3 +263,6 @@ index((rdf_read_turtle), 3, turtle, turtle).
 index((rdf_process_turtle), 3, turtle, turtle).
 index((rdf_save_turtle), 2, turtle, turtle).
 index((rdf_save_canonical_turtle), 2, turtle, turtle).
+index((rdf_save_trig), 2, turtle, turtle).
+index((rdf_save_canonical_trig), 2, turtle, turtle).
+index((rdf_save_ntriples), 2, turtle, turtle).
