@@ -3,36 +3,41 @@
     Author:        Jeffrey Rosenwald
     E-mail:        jeffrose@acm.org
     WWW:           http://www.swi-prolog.org
-    Copyright (C): 2012, Jeffrey Rosenwald
+    Copyright (c)  2012-2013, Jeffrey Rosenwald
+    All rights reserved.
 
-    This program is free software; you can redistribute it and/or
-    modify it under the terms of the GNU General Public License
-    as published by the Free Software Foundation; either version 2
-    of the License, or (at your option) any later version.
+    Redistribution and use in source and binary forms, with or without
+    modification, are permitted provided that the following conditions
+    are met:
 
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
+    1. Redistributions of source code must retain the above copyright
+       notice, this list of conditions and the following disclaimer.
 
-    You should have received a copy of the GNU General Public
-    License along with this library; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+    2. Redistributions in binary form must reproduce the above copyright
+       notice, this list of conditions and the following disclaimer in
+       the documentation and/or other materials provided with the
+       distribution.
 
-    As a special exception, if you link this library with other files,
-    compiled with a Free Software compiler, to produce an executable, this
-    library does not by itself cause the resulting executable to be covered
-    by the GNU General Public License. This exception does not however
-    invalidate any other reasons why the executable file might be covered by
-    the GNU General Public License.
+    THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
+    "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
+    LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
+    FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
+    COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
+    INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
+    BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
+    LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
+    CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
+    LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN
+    ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
+    POSSIBILITY OF SUCH DAMAGE.
 */
 
 :- module(udp_broadcast,
              [
-	     udp_host_to_address/2,    % ? Host, ? Address
-	     udp_broadcast_initialize/2,   % +IPAddress, +Subnet
-	     udp_broadcast_service/2   % ? Domain, ? Address
-	     ]).
+             udp_host_to_address/2,    % ? Host, ? Address
+             udp_broadcast_initialize/2,   % +IPAddress, +Subnet
+             udp_broadcast_service/2   % ? Domain, ? Address
+             ]).
 
 /** <module> A UDP Broadcast Bridge
 
@@ -131,7 +136,7 @@ Host A Process 2:
 
 ==
 
----++ Caveats:
+## Caveats {#udp-broadcase-caveats}
 
 While the implementation is mostly transparent, there are some important
 and subtle differences that must be taken into consideration:
@@ -215,7 +220,7 @@ and subtle differences that must be taken into consideration:
     people honest!
 
 @author    Jeffrey Rosenwald (JeffRose@acm.org)
-@license   LGPL
+@license   BSD-2
 @see       tipc.pl
 */
 
@@ -224,15 +229,15 @@ and subtle differences that must be taken into consideration:
 :- use_module(library(time)).
 
 :- require([ thread_self/1
-	   , forall/2
-	   , term_to_atom/2
-	   , thread_send_message/2
-	   , catch/3
-	   , setup_call_cleanup/3
-	   , thread_create/3
-	   ]).
+           , forall/2
+           , term_to_atom/2
+           , thread_send_message/2
+           , catch/3
+           , setup_call_cleanup/3
+           , thread_create/3
+           ]).
 
-% %	~>(:P, :Q) is nondet.
+% %     ~>(:P, :Q) is nondet.
 % %     eventually_implies(P, Q) is nondet.
 %    asserts temporal Liveness (something good happens, eventually) and
 %    Safety (nothing bad ever happens) properties. Analogous to the
@@ -252,57 +257,57 @@ and subtle differences that must be taken into consideration:
 :- op(950, xfy, ~>).
 
 ~>(P, Q) :-
-	setup_call_cleanup(P,
-			   (true; fail),
-			   (   Q -> true;
-			   throw(error(goal_failed(Q), context(~>, _))))
-			  ).
+    setup_call_cleanup(P,
+                       (true; fail),
+                       (   Q -> true;
+                       throw(error(goal_failed(Q), context(~>, _))))
+                      ).
 
 :- meta_predicate safely(0).
 
 safely(Predicate) :-
-	catch(Predicate, Err,
-	      (Err == '$aborted' -> (!, fail);
-	      print_message(error, Err), fail)).
+    catch(Predicate, Err,
+          (Err == '$aborted' -> (!, fail);
+          print_message(error, Err), fail)).
 
 :- meta_predicate make_thread(0, +).
 
 % You can't thread_signal a thread that isn't running.
 
 join_thread(Id) :-
-       catch(thread_signal(Id, abort),
-	     error(existence_error(thread, Id), _Context),
-	     true),
+    catch(thread_signal(Id, abort),
+          error(existence_error(thread, Id), _Context),
+          true),
 
-       thread_join(Id, exception('$aborted')).
+    thread_join(Id, exception('$aborted')).
 
 make_thread(Goal, Options) :-
-	thread_create(safely(Goal), Id, [ detached(false) | Options ])
-	  ~> join_thread(Id).
+    thread_create(safely(Goal), Id, [ detached(false) | Options ])
+      ~> join_thread(Id).
 
 udp_broadcast_address(IPAddress, Subnet, BroadcastAddress) :-
-	IPAddress = ip(A1, A2, A3, A4),
-	Subnet = ip(S1, S2, S3, S4),
-	BroadcastAddress = ip(B1, B2, B3, B4),
+    IPAddress = ip(A1, A2, A3, A4),
+    Subnet = ip(S1, S2, S3, S4),
+    BroadcastAddress = ip(B1, B2, B3, B4),
 
-	B1 is A1 \/ (S1 xor 255),
-	B2 is A2 \/ (S2 xor 255),
-	B3 is A3 \/ (S3 xor 255),
-	B4 is A4 \/ (S4 xor 255).
+    B1 is A1 \/ (S1 xor 255),
+    B2 is A2 \/ (S2 xor 255),
+    B3 is A3 \/ (S3 xor 255),
+    B4 is A4 \/ (S4 xor 255).
 
-%%	udp_broadcast_service(?Domain, ?Address) is nondet.
+%!  udp_broadcast_service(?Domain, ?Address) is nondet.
 %   provides the UDP broadcast address for a given Domain. At present,
 %   only one domain is supported, =|udp_subnet|=.
 %
 
 %  The following are defined at initialization:
 :- dynamic
-	udp_subnet_member/1,      % +IpAddress:Port
-	udp_broadcast_service/2.  % ?Domain, ?BroadcastAddress:Port
+    udp_subnet_member/1,      % +IpAddress:Port
+    udp_broadcast_service/2.  % ?Domain, ?BroadcastAddress:Port
 
 :- volatile
-	udp_subnet_member/1,      % +IpAddress:Port
-	udp_broadcast_service/2.  % ?Domain, ?BroadcastAddress:Port
+    udp_subnet_member/1,      % +IpAddress:Port
+    udp_broadcast_service/2.  % ?Domain, ?BroadcastAddress:Port
 %
 %  Here's a UDP bridge to Prolog's broadcast library
 %
@@ -348,154 +353,162 @@ black_list(tipc_zone(_)).
 black_list(tipc_zone(_,_)).
 %
 ld_dispatch(_S, '$udp_request'(Term), _From) :-
-	black_list(Term), !, fail.
+    black_list(Term), !, fail.
 
 ld_dispatch(_S, Term, _From) :-
-	black_list(Term), !, fail.
+    black_list(Term), !, fail.
 
 ld_dispatch(S, '$udp_request'(wru(Name)), From) :-
-	!, gethostname(Name),
-	term_to_atom(wru(Name), Atom),
-	udp_send(S, Atom, From, []).
+    !, gethostname(Name),
+    term_to_atom(wru(Name), Atom),
+    udp_send(S, Atom, From, []).
 
 ld_dispatch(S, '$udp_request'(Term), From) :-
-	!, forall(broadcast_request(Term),
-	      (   term_to_atom(Term, Atom),
-		  udp_send(S, Atom, From, []))).
+    !, forall(broadcast_request(Term),
+          (   term_to_atom(Term, Atom),
+              udp_send(S, Atom, From, []))).
 
 ld_dispatch(_S, Term, _From) :-
-	safely(broadcast(Term)).
+    safely(broadcast(Term)).
 
 %  Thread 1 listens for directed traffic on the private port.
 %
 udp_listener_daemon1(S) :-
-	repeat,
-	safely(dispatch_traffic(S, S)).
+    repeat,
+    safely(dispatch_traffic(S, S)).
 
 %  Thread 2 listens for broadcast traffic on the well-known public port
 %  (S). All replies are originated from the private port (S1).
 %
 udp_listener_daemon2(Parent) :-
-	udp_socket(S) ~> tcp_close_socket(S),
-	udp_socket(S1) ~> tcp_close_socket(S1),
+    udp_socket(S) ~> tcp_close_socket(S),
+    udp_socket(S1) ~> tcp_close_socket(S1),
 
-	tcp_bind(S1, _PrivatePort),   % bind him to a private port now
+    tcp_bind(S1, _PrivatePort),   % bind him to a private port now
 
-	make_thread(udp_listener_daemon1(S1),
-		    [ alias(udp_listener_daemon1)]),
+    make_thread(udp_listener_daemon1(S1),
+                [ alias(udp_listener_daemon1)]),
 
-	tcp_setopt(S, reuseaddr),
+    tcp_setopt(S, reuseaddr),
 
-	udp_broadcast_service(udp_subnet, _Address:Port),
-	tcp_bind(S, Port),      % bind to our public port
+    udp_broadcast_service(udp_subnet, _Address:Port),
+    tcp_bind(S, Port),      % bind to our public port
 
-	listen(udp_broadcast, Head, broadcast_listener(Head))
-	     ~> unlisten(udp_broadcast),
+    listen(udp_broadcast, Head, broadcast_listener(Head))
+         ~> unlisten(udp_broadcast),
 
-	thread_send_message(Parent, udp_listener_daemon_ready),
+    thread_send_message(Parent, udp_listener_daemon_ready),
 
-	repeat,
-	safely(dispatch_traffic(S, S1)).
+    repeat,
+    safely(dispatch_traffic(S, S1)).
 
 dispatch_traffic(S, S1) :-
-	udp_receive(S, Data, From,
-		    [as(atom), max_message_size(65535)]),
-	udp_subnet_member(From),  % ignore all traffic that is foreign to my subnet
-	term_to_atom(Term, Data),
-	with_mutex(udp_broadcast, ld_dispatch(S1, Term, From)), !,
-	dispatch_traffic(S, S1).
+    udp_receive(S, Data, From,
+                [as(atom), max_message_size(65535)]),
+    udp_subnet_member(From),  % ignore all traffic that is foreign to my subnet
+    term_to_atom(Term, Data),
+    with_mutex(udp_broadcast, ld_dispatch(S1, Term, From)),
+    !,
+    dispatch_traffic(S, S1).
 
 start_udp_listener_daemon :-
-	catch(thread_property(udp_listener_daemon2, status(running)),_, fail),
-	!.
+    catch(thread_property(udp_listener_daemon2, status(running)),_, fail),
+
+    !.
 
 start_udp_listener_daemon :-
-	thread_self(Self),
-	thread_create(udp_listener_daemon2(Self), _,
-	       [alias(udp_listener_daemon2), detached(true)]),
-	call_with_time_limit(6.0,
-			     thread_get_message(udp_listener_daemon_ready)).
+    thread_self(Self),
+    thread_create(udp_listener_daemon2(Self), _,
+           [alias(udp_listener_daemon2), detached(true)]),
+    call_with_time_limit(6.0,
+                         thread_get_message(udp_listener_daemon_ready)).
 
 :- multifile udp:host_to_address/2.
 %
 broadcast_listener(udp_host_to_address(Host, Addr)) :-
-	udp:host_to_address(Host, Addr).
+    udp:host_to_address(Host, Addr).
 
 broadcast_listener(udp_broadcast_service(Class, Addr)) :-
-	udp_broadcast_service(Class, Addr).
+    udp_broadcast_service(Class, Addr).
 
 broadcast_listener(udp_subnet(X)) :-
-	udp_broadcast(X, udp_subnet, 0.250).
+    udp_broadcast(X, udp_subnet, 0.250).
 
 broadcast_listener(udp_subnet(X, Timeout)) :-
-	udp_broadcast(X, udp_subnet, Timeout).
+    udp_broadcast(X, udp_subnet, Timeout).
 
 %
 %
 udp_basic_broadcast(S, Port, Term, Address) :-
-	udp_socket(S)
-	  ~> tcp_close_socket(S),
+    udp_socket(S)
+      ~> tcp_close_socket(S),
 
-	(   udp_broadcast_service(udp_subnet, Address)
-	       -> tcp_setopt(S, broadcast)
-	       ; true
-	),
+    (   udp_broadcast_service(udp_subnet, Address)
+           -> tcp_setopt(S, broadcast)
+           ; true
+    ),
 
-	tcp_bind(S, Port),  % find our own ephemeral Port
-	term_to_atom(Term, Atom),
+    tcp_bind(S, Port),  % find our own ephemeral Port
+    term_to_atom(Term, Atom),
 
-	(   udp_subnet_member(Address)  % talk only to your local subnet
-	    -> safely(udp_send(S, Atom, Address, []))
-	    ;  true).
+    (   udp_subnet_member(Address)  % talk only to your local subnet
+        -> safely(udp_send(S, Atom, Address, []))
+        ;  true).
 
 % directed broadcast to a single listener
 udp_broadcast(Term:To, _Scope, _Timeout) :-
-	ground(Term), ground(To), !,
-	udp_basic_broadcast(_S, _Port, Term, To),
-	!.
+    ground(Term), ground(To),
+    !,
+    udp_basic_broadcast(_S, _Port, Term, To),
+
+    !.
 
 % broadcast to all listeners
 udp_broadcast(Term, Scope, _Timeout) :-
-	ground(Term), !,
-	udp_broadcast_service(Scope, Address),
-	udp_basic_broadcast(_S, _Port, Term, Address),
-	!.
+    ground(Term),
+    !,
+    udp_broadcast_service(Scope, Address),
+    udp_basic_broadcast(_S, _Port, Term, Address),
+
+    !.
 
 % directed broadcast_request to a single listener
 udp_broadcast(Term:Address, _Scope, Timeout) :-
-	ground(Address), !,
-        udp_basic_broadcast(S, Port, '$udp_request'(Term), Address),
-	udp_br_collect_replies(S, Port, Timeout, Term:Address).
+    ground(Address),
+    !,
+    udp_basic_broadcast(S, Port, '$udp_request'(Term), Address),
+    udp_br_collect_replies(S, Port, Timeout, Term:Address).
 
 % broadcast_request to all listeners returning responder port-id
 udp_broadcast(Term:From, Scope, Timeout) :-
-	!, udp_broadcast_service(Scope, Address),
-        udp_basic_broadcast(S, Port, '$udp_request'(Term), Address),
-	udp_br_collect_replies(S, Port, Timeout, Term:From).
+    !, udp_broadcast_service(Scope, Address),
+    udp_basic_broadcast(S, Port, '$udp_request'(Term), Address),
+    udp_br_collect_replies(S, Port, Timeout, Term:From).
 
 % broadcast_request to all listeners ignoring responder port-id
 udp_broadcast(Term, Scope, Timeout) :-
-	udp_broadcast(Term:_, Scope, Timeout).
+    udp_broadcast(Term:_, Scope, Timeout).
 
 udp_br_send_timeout(Port) :-
-	udp_socket(S)
-	  ~> tcp_close_socket(S),
-	udp_send(S, '$udp_br_timeout', localhost:Port, []),
-	!.
+    udp_socket(S)
+      ~> tcp_close_socket(S),
+    udp_send(S, '$udp_br_timeout', localhost:Port, []),
+
+    !.
 
 udp_br_collect_replies(S, Port, Timeout, Term:From) :-
-	alarm(Timeout, udp_br_send_timeout(Port), Id, [remove(false)])
-	  ~> remove_alarm(Id),
+    alarm(Timeout, udp_br_send_timeout(Port), Id, [remove(false)])
+      ~> remove_alarm(Id),
 
-	tcp_setopt(S, dispatch(false)),
+    tcp_setopt(S, dispatch(false)),
 
-	repeat,
-        udp_receive(S, Atom, From1, [as(atom)]),
-        (   (Atom \== '$udp_br_timeout')
-	    -> (From1 = From, safely(term_to_atom(Term, Atom)))
-	    ;  (!, fail)).
+    repeat,
+    udp_receive(S, Atom, From1, [as(atom)]),
+    (   (Atom \== '$udp_br_timeout')
+        -> (From1 = From, safely(term_to_atom(Term, Atom)))
+        ;  (!, fail)).
 
-%%	udp_host_to_address(?Service, ?Address) is nondet.
+%!  udp_host_to_address(?Service, ?Address) is nondet.
 %
 %   locates a UDP service by name. Service  is an atom or grounded term
 %   representing the common name  of  the   service.  Address  is a UDP
@@ -507,15 +520,15 @@ udp_br_collect_replies(S, Port, Timeout, Term:From) :-
 %
 
 udp_host_to_address(Host, Address) :-
-	broadcast_request(udp_subnet(udp_host_to_address(Host, Address))).
+    broadcast_request(udp_subnet(udp_host_to_address(Host, Address))).
 
-%%	udp_initialize is semidet.
+%!  udp_initialize is semidet.
 %   See udp:udp_initialize/0
 %
 %:- multifile udp:udp_stack_initialize/0.
 
 
-%%      udp_broadcast_initialize(+IPAddress, +SubnetMask) is semidet.
+%!  udp_broadcast_initialize(+IPAddress, +SubnetMask) is semidet.
 %   causes any required runtime initialization to occur. At present,
 %   proper operation of UDP broadcast depends on local information
 %   that is not easily obtained mechanically. In order to determine
@@ -526,11 +539,11 @@ udp_host_to_address(Host, Address) :-
 %
 
 udp_broadcast_initialize(IPAddress, Subnet) :-
-	retractall(udp_broadcast_service(_,_)),
-	retractall(udp_subnet_member(_)),
+    retractall(udp_broadcast_service(_,_)),
+    retractall(udp_subnet_member(_)),
 
-	udp_broadcast_address(IPAddress, Subnet, BroadcastAddr),
-	assert(udp_broadcast_service(udp_subnet, BroadcastAddr:20005)),
-	assert(udp_subnet_member(Address:_Port) :- udp_broadcast_address(Address, Subnet, BroadcastAddr)),
+    udp_broadcast_address(IPAddress, Subnet, BroadcastAddr),
+    assert(udp_broadcast_service(udp_subnet, BroadcastAddr:20005)),
+    assert(udp_subnet_member(Address:_Port) :- udp_broadcast_address(Address, Subnet, BroadcastAddr)),
 
-	start_udp_listener_daemon.
+    start_udp_listener_daemon.
